@@ -12,8 +12,8 @@ typedef enum {
 } poly_order;
 
 enum {
-	INTER_POLY = 0,
-	INTER_RBF = 1
+	INTER_RBF = 0,
+	INTER_POLY = 1
 };
 
 struct background_data {
@@ -23,8 +23,10 @@ struct background_data {
     int interpolation_method;
 	poly_order degree;
 	double smoothing;
+	int threads;
 	gboolean dither;
 	fits *fit;
+	gboolean from_ui;
 	sequence *seq;
 	const gchar *seqEntry;
 };
@@ -36,7 +38,7 @@ void free_background_sample_list(GSList *list);
 GSList* add_background_sample(GSList *list, fits *fit, point pt);
 GSList* remove_background_sample(GSList *orig, fits *fit, point pt);
 void generate_background_samples(int nb_of_samples, double tolerance);
-gboolean remove_gradient_from_image(int correction, poly_order degree, double smoothing, gboolean use_dither, int interpolation_method);
+gpointer remove_gradient_from_image(gpointer p);
 void apply_background_extraction_to_sequence(struct background_data *background_args);
 
 gboolean background_sample_is_valid(background_sample *sample);
