@@ -2,7 +2,8 @@
 #define _DEMOSAICING_H
 
 extern const char *filter_pattern[];
-int retrieveBayerPatternFromChar(char *bayer);
+extern const size_t num_filter_patterns;
+int retrieveBayerPatternFromChar(const char *bayer);
 
 WORD *debayer_buffer(WORD *buf, int *width, int *height,
 		interpolation_method interpolation, sensor_pattern pattern, int bit_depth);
