@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -76,16 +76,15 @@ static double dhampel(double x) {
 static double qmedD(int n, double *a)
 	/* Vypocet medianu algoritmem Quick Median (Wirth) */
 {
-	double w, x;
-	int i, j;
+	double w;
 	int k = ((n & 1) ? (n / 2) : ((n / 2) - 1));
 	int l = 0;
 	int r = n - 1;
 
 	while (l < r) {
-		x = a[k];
-		i = l;
-		j = r;
+		double x = a[k];
+		int i = l;
+		int j = r;
 		do {
 			while (a[i] < x)
 				i++;
@@ -111,7 +110,7 @@ static int robustmean(int n, double *x, double *mean, double *stdev)
 	/* Newton's iterations */
 {
 	int i, it;
-	double a, c, d, dt, r, s, sum1, sum2, sum3, psir;
+	double a, c, dt, r, s, psir;
 	double *xx;
 
 	if (n < 1) {
@@ -161,6 +160,7 @@ static int robustmean(int n, double *x, double *mean, double *stdev)
 	dt = 0;
 	c = s * s * n * n / (n - 1);
 	for (it = 1; it <= maxit; it++) {
+		double sum1, sum2, sum3;
 		sum1 = sum2 = sum3 = 0.0;
 		for (i = 0; i < n; i++) {
 			r = (x[i] - a) / s;
@@ -171,7 +171,7 @@ static int robustmean(int n, double *x, double *mean, double *stdev)
 		}
 		if (fabs(sum2) < epsilon(sum2))
 			break;
-		d = s * sum1 / sum2;
+		double d = s * sum1 / sum2;
 		a = a + d;
 		dt = c * sum3 / (sum2 * sum2);
 		if ((it > 2) && ((d * d < 1e-4 * dt) || (fabs(d) < 10.0 * epsilon(d))))
@@ -214,10 +214,15 @@ static double getOuterRadius() {
 	return com.pref.phot_set.outer;
 }
 
-static double getMagErr(double intensity, double area, int nsky, double skysig) {
+static double getAperture() {
+	return com.pref.phot_set.aperture;
+}
+
+static double getMagErr(double intensity, double area, int nsky, double skysig, double *SNR) {
 	double skyvar, sigsq;
 	double err1, err2, err3;
 	double phpadu;
+	double noise;
 
 	skyvar = skysig * skysig; /* variance of the sky brightness */
 	sigsq = skyvar / nsky; /* square of the standard error of the mean sky brightness */
@@ -225,8 +230,11 @@ static double getMagErr(double intensity, double area, int nsky, double skysig)
 	err1 = area * skyvar;
 	err2 = intensity / phpadu;
 	err3 = sigsq * area * area;
+	noise = sqrt(err1 + err2 + err3);
 
-	return fmin(9.999, 1.0857 * sqrt(err1 + err2 + err3) / intensity);
+	*SNR = 10.0 * log10(intensity / noise);
+
+	return fmin(9.999, 1.0857 * noise / intensity);
 }
 
 static double lo_data() {
@@ -246,7 +254,7 @@ static double hi_data() {
 }
 
 /* Function that compute all photometric data. The result must be freed */
-photometry *getPhotometryData(gsl_matrix* z, fitted_PSF *psf, gboolean verbose) {
+photometry *getPhotometryData(gsl_matrix* z, psf_star *psf, gboolean force_radius, gboolean verbose) {
 	int width = z->size2;
 	int height = z->size1;
 	int n_sky = 0, ret;
@@ -254,7 +262,6 @@ photometry *getPhotometryData(gsl_matrix* z, fitted_PSF *psf, gboolean verbose)
 	double r1, r2, r, rmin_sq, appRadius;
 	double xc, yc;
 	double apmag = 0.0, mean = 0.0, stdev = 0.0, area = 0.0;
-	double signalIntensity;
 	gboolean valid = TRUE;
 	photometry *phot;
 
@@ -265,8 +272,8 @@ photometry *getPhotometryData(gsl_matrix* z, fitted_PSF *psf, gboolean verbose)
 
 	r1 = getInnerRadius();
 	r2 = getOuterRadius();
-	appRadius = psf->fwhmx * 2.0;	// in order to be sure to contain star
-	if (appRadius >= r1) {
+	appRadius = force_radius ? getAperture() : psf->fwhmx * 2.0;	// in order to be sure to contain star
+	if (appRadius >= r1 && !force_radius) {
 		if (verbose) {
 			/* Translator note: radii is plural for radius */
 			siril_log_message(_("Inner and outer radii are too small. Please update values in preferences.\n"));
@@ -344,10 +351,14 @@ photometry *getPhotometryData(gsl_matrix* z, fitted_PSF *psf, gboolean verbose)
 
 	phot = phot_alloc();
 	if (phot) {
-		signalIntensity = apmag - (area * mean);
+		double SNR = 0.0;
+
+		double signalIntensity = apmag - (area * mean);
 
 		phot->mag = getMagnitude(signalIntensity);
-		phot->s_mag = getMagErr(signalIntensity, area, n_sky, stdev);
+		phot->s_mag = getMagErr(signalIntensity, area, n_sky, stdev, &SNR);
+		phot->SNR = phot->s_mag < 9.999 ? SNR : 0.0;
+		valid = phot->s_mag < 9.999 ? valid : FALSE;
 		phot->valid = valid;
 	}
 
@@ -357,6 +368,8 @@ photometry *getPhotometryData(gsl_matrix* z, fitted_PSF *psf, gboolean verbose)
 void initialize_photometric_param() {
 	com.pref.phot_set.inner = 20;
 	com.pref.phot_set.outer = 30;
+	com.pref.phot_set.aperture = 10;
+	com.pref.phot_set.force_radius = FALSE;
 	com.pref.phot_set.gain = 2.3;
 	com.pref.phot_set.minval = 0;
 	com.pref.phot_set.maxval = 60000;
