@@ -24,9 +24,9 @@
 #include "gui/utils.h"
 #include "gui/image_display.h"
 #include "gui/progress_and_log.h"
-#include "algos/plateSolver.h"
 #include "algos/annotate.h"
 #include "algos/siril_wcs.h"
+#include "astrometry_solver.h"
 
 static gboolean parse_buffer(char *buffer) {
 	char **token, **fields, *realname= NULL;
@@ -65,7 +65,7 @@ static gboolean parse_buffer(char *buffer) {
 
 void on_search_objects_entry_activate(GtkEntry *entry, gpointer user_data) {
 	if (!has_wcs(&gfit)) return;
-	gchar *result = search_in_catalogs(gtk_entry_get_text(GTK_ENTRY(entry)));
+	gchar *result = search_in_catalogs(gtk_entry_get_text(GTK_ENTRY(entry)), FALSE);
 	if (result) {
 		if (parse_buffer(result)) {
 			GtkToggleToolButton *button = GTK_TOGGLE_TOOL_BUTTON(lookup_widget("annotate_button"));
@@ -73,7 +73,7 @@ void on_search_objects_entry_activate(GtkEntry *entry, gpointer user_data) {
 				gtk_toggle_tool_button_set_active(button, TRUE);
 			} else {
 				force_to_refresh_catalogue_list();
-				redraw(com.cvport, REMAP_NONE);
+				redraw(REDRAW_OVERLAY);
 			}
 			gtk_entry_set_text(GTK_ENTRY(entry), "");
 			siril_close_dialog("search_objects");
