@@ -696,7 +696,7 @@ static int stat_image_hook(struct generic_seq_args *args, int o, int i, fits *fi
 			}
 		}
 
-		int new_index = i * s_args->seq->nb_layers;
+		int new_index = o * s_args->seq->nb_layers;
 
 		if (fit->type == DATA_USHORT) {
 			if (s_args->option == (STATS_BASIC)) {
