@@ -4,6 +4,7 @@
 struct stat_data {
 	fits *fit;
 	int option;
+	rectangle selection;
 	gchar **list;
 	sequence *seq;
 	gchar *csv_name;
@@ -30,7 +31,7 @@ struct stat_data {
 imstats* statistics(sequence *seq, int image_index, fits *fit, int layer,
 		rectangle *selection, int option, gboolean multithread);
 
-int compute_means_from_flat_cfa(fits *fit, float mean[4]);
+int compute_means_from_flat_cfa(fits *fit, double mean[36]);
 
 void allocate_stats(imstats **stat);
 imstats* free_stats(imstats *stat);
@@ -52,6 +53,6 @@ float siril_stats_ushort_sd_32(const WORD data[], const int N);
 float siril_stats_ushort_mad(const WORD* data, const size_t n, const double m, gboolean multithread);
 float siril_stats_float_sd(const float data[], const int N, float *mean);
 double siril_stats_float_mad(const float *data, const size_t n, const double m, gboolean multithread, float *buffer);
+float siril_stats_trmean_from_sorted_data(const float trim, const float sorted_data[], const size_t stride, const size_t size);
 
 #endif
-
