@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -133,6 +133,26 @@ static double siril_stats_float_bwmv(const float* data, const size_t n,
 	return bwmv;
 }
 
+float siril_stats_trmean_from_sorted_data(const float trim,
+		const float sorted_data[], const size_t stride, const size_t size) {
+	if (trim >= 0.5f) {
+		return (float) gsl_stats_float_median_from_sorted_data(sorted_data, stride, size);
+	} else {
+		size_t ilow = (size_t) floorf(trim * size);
+		size_t ihigh = size - ilow - 1;
+		float mean = 0.f;
+		float k = 0.f;
+
+		/* compute mean of middle samples in [ilow,ihigh] */
+		for (size_t i = ilow; i <= ihigh; ++i) {
+			float delta = sorted_data[i * stride] - mean;
+			k += 1.f;
+			mean += delta / k;
+		}
+		return mean;
+	}
+}
+
 #if 0
 int IKSS(float *data, size_t n, double *location, double *scale, gboolean multithread) {
 	size_t i, j;
@@ -205,8 +225,10 @@ int IKSSlite(float *data, size_t n, const float median, float mad, double *locat
 
 	*location = histogram_median_float(data, kept, multithread);
 	mad = siril_stats_float_mad(data, kept, *location, multithread, NULL);
-	if (mad == 0.0f)
+	if (mad == 0.0f) {
+		siril_log_color_message(_("MAD is null. Statistics cannot be computed.\n"), "red");
 		return 1;
+	}
 
 	*scale = sqrt(siril_stats_float_bwmv(data, kept, mad, *location, multithread)) *.991;
 	/* 0.991 factor is to keep consistency with IKSS scale */
@@ -430,13 +452,12 @@ imstats* statistics_internal_float(fits *fit, int layer, rectangle *selection, i
 	return stat;
 }
 
-int compute_means_from_flat_cfa_float(fits *fit, float mean[4]) {
-	int row, col, c, i = 0;
+int compute_means_from_flat_cfa_float(fits *fit, double mean[36]) {
+	int row, col, c, i[36] = {0};
 	float *data;
 	unsigned int width, height;
 	unsigned int startx, starty;
 
-	mean[0] = mean[1] = mean[2] = mean[3] = 0.0;
 	data = fit->fdata;
 	width = fit->rx;
 	height = fit->ry;
@@ -447,26 +468,19 @@ int compute_means_from_flat_cfa_float(fits *fit, float mean[4]) {
 	startx = width / 3;
 	starty = height / 3;
 
-	/* make sure it does start at the beginning of CFA pattern */
-	startx = startx % 2 == 0 ? startx : startx + 1;
-	starty = starty % 2 == 0 ? starty : starty + 1;
-
 	siril_debug_print("Computing stat in (%d, %d, %d, %d)\n", startx, starty,
 			width - 1 - startx, height - 1 - starty);
 
-	/* Compute mean of each channel */
-	for (row = starty; row < height - 1 - starty; row += 2) {
-		for (col = startx; col < width - 1 - startx; col += 2) {
-			mean[0] += data[col + row * width];
-			mean[1] += data[1 + col + row * width];
-			mean[2] += data[col + (1 + row) * width];
-			mean[3] += data[1 + col + (1 + row) * width];
-			i++;
+	/* compute mean of each element in 6x6 blocks */
+	for (row = starty; row < height - starty; row++) {
+		for (col = startx; col < width - startx; col++) {
+			mean[(col % 6) + (row % 6) * 6] += data[col + row * width];
+			i[(col % 6) + (row % 6) * 6]++;
 		}
 	}
 
-	for (c = 0; c < 4; c++) {
-		mean[c] /= (float) i;
+	for (c = 0; c < 36; c++) {
+		mean[c] /= (double) i[c];
 	}
 	return 0;
 }
