@@ -10,6 +10,7 @@ int	process_asinh(int nb);
 
 int	process_bg(int nb);
 int	process_bgnoise(int nb);
+int	process_boxselect(int nb);
 
 int	process_cd(int nb);
 int	process_cdg(int nb);
@@ -55,9 +56,7 @@ int	process_link(int nb);
 int	process_linear_match(int nb);
 int	process_load(int nb);
 int	process_log(int nb);
-#ifndef _WIN32
 int	process_ls(int nb);
-#endif
 
 int	process_merge(int nb);
 int	process_mirrorx(int nb);
@@ -111,11 +110,12 @@ int	process_set_mag(int nb);
 int	process_set_mag_seq(int nb);
 int	process_set_mem(int nb);
 int	process_set_ref(int nb);
+int process_seq_cosme(int nb);
 int	process_seq_crop(int nb);
 int	process_seq_mtf(int nb);
 int	process_seq_psf(int nb);
 int	process_seq_split_cfa(int nb);
-int process_seq_stat(int nb);
+int	process_seq_stat(int nb);
 int	process_subsky(int nb);
 int	process_split(int nb);
 int	process_split_cfa(int nb);
@@ -126,6 +126,7 @@ int	process_stackone(int nb);
 int	process_thresh(int nb);
 int	process_threshlo(int nb);
 int	process_threshhi(int nb);
+int	process_tilt(int nb);
 
 int	process_unset_mag(int nb);
 int	process_unset_mag_seq(int nb);
