@@ -28,8 +28,10 @@ enum token_index {
 	PRE = 3,	/* Preprocessing settings */
 	REG = 4,	/* Registration settings */
 	STK = 5,	/* Stacking settings */
-	PTM = 6,	/* Photometry settings */
-	MISC = 7,	/* Miscellaneous settings */
+	AST = 6,	/* Astrometry settings */
+	PTM = 7,	/* Photometry settings */
+	MISC = 8,	/* Miscellaneous settings */
+	CMP = 9,	/* Compression settings */
 	NOTOK
 };
 
