@@ -296,7 +296,7 @@ static int prepro_prepare_hook(struct generic_seq_args *args) {
 			const unsigned int startx = width / 3;
 			const unsigned int starty = height / 3;
 
-			rectangle selection = { startx, starty, width - 1 - startx, height - 1 - starty };
+			rectangle selection = { startx, starty, startx, starty };
 
 			imstats *stat = statistics(NULL, -1, prepro->flat, RLAYER, &selection, STATS_BASIC, FALSE);
 			if (!stat) {
