@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -78,9 +78,8 @@ gpointer generic_sequence_worker(gpointer p) {
 		args->retval = 1;
 		goto the_end;
 	}
-	if (args->compute_mem_limits_hook)
-		siril_log_message(_("%s: with the current memory and thread limits, up to %d thread(s) can be used\n"),
-				args->description, args->max_thread);
+	siril_log_message(_("%s: with the current memory and thread limits, up to %d thread(s) can be used\n"),
+			args->description, args->max_thread);
 #endif
 
 	if (args->prepare_hook && args->prepare_hook(args)) {
@@ -346,7 +345,8 @@ gboolean end_generic_sequence(gpointer p) {
  */
 int seq_compute_mem_limits(struct generic_seq_args *args, gboolean for_writer) {
 	unsigned int MB_per_image, MB_avail;
-	int limit = compute_nb_images_fit_memory(args->seq, args->upscale_ratio, args->force_float, NULL, &MB_per_image, &MB_avail);
+	int thread_limit = compute_nb_images_fit_memory(args->seq, args->upscale_ratio, args->force_float, NULL, &MB_per_image, &MB_avail);
+	int limit = thread_limit;
 	if (limit == 0) {
 		gchar *mem_per_image = g_format_size_full(MB_per_image * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
 		gchar *mem_available = g_format_size_full(MB_avail * BYTES_IN_A_MB, G_FORMAT_SIZE_IEC_UNITS);
@@ -358,18 +358,26 @@ int seq_compute_mem_limits(struct generic_seq_args *args, gboolean for_writer) {
 		g_free(mem_available);
 	} else {
 #ifdef _OPENMP
-		if (for_writer) {
-			int max_queue_size = com.max_thread * 3;
-			if (limit > max_queue_size)
-				limit = max_queue_size;
-		}
-		else if (limit > com.max_thread)
+		/* number of threads for the main computation */
+		if (limit > com.max_thread)
 			limit = com.max_thread;
+		if (for_writer) {
+			/* we take the remainder for the writer */
+			int max_queue_size = com.max_thread * 3;
+			if (thread_limit - limit > max_queue_size)
+				limit = max_queue_size;
+			else limit = thread_limit - limit;
+			if (limit < 1)
+				limit = 1;	// bug #777
+		}
 #else
 		if (!for_writer)
 			limit = 1;
-		else if (limit > 3)
-			limit = 3;
+		else {
+			limit = max(1, limit-1);
+			if (limit > 3)
+				limit = 3;
+		}
 #endif
 	}
 	return limit;
@@ -492,6 +500,7 @@ void start_in_new_thread(gpointer (*f)(gpointer), gpointer p) {
 
 	com.run_thread = TRUE;
 	g_mutex_unlock(&com.mutex);
+	set_cursor_waiting(TRUE);
 	com.thread = g_thread_new("processing", f, p);
 }
 
@@ -506,6 +515,7 @@ void start_in_reserved_thread(gpointer (*f)(gpointer), gpointer p) {
 
 	com.run_thread = TRUE;
 	g_mutex_unlock(&com.mutex);
+	set_cursor_waiting(TRUE);
 	com.thread = g_thread_new("processing", f, p);
 }
 
@@ -579,10 +589,17 @@ guint siril_add_idle(GSourceFunc idle_function, gpointer data) {
 	return 0;
 }
 
+gboolean get_script_thread_run() {
+	/* we don't need mutex for this one because it's only checked by user
+	 * input, which is much slower than the function execution */
+	return com.script_thread != NULL;
+}
+
 void wait_for_script_thread() {
-	if (com.script_thread)
+	if (com.script_thread) {
 		g_thread_join(com.script_thread);
-	com.script_thread = NULL;
+		com.script_thread = NULL;
+	}
 }
 
 void on_processes_button_cancel_clicked(GtkButton *button, gpointer user_data) {
