@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -18,7 +18,6 @@
  * along with Siril. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtk/gtk.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -34,11 +33,13 @@
 #include "gui/image_display.h"
 #include "gui/histogram.h"
 #include "gui/progress_and_log.h"
+#include "gui/registration_preview.h"
 #include "io/sequence.h"
 #include "io/image_format_fits.h"
 #include "io/single_image.h"
 #include "algos/colors.h"
 #include "algos/statistics.h"
+#include "algos/demosaicing.h"
 #include "opencv/opencv.h"
 
 int threshlo(fits *fit, WORD level) {
@@ -208,6 +209,10 @@ int loglut(fits *fit) {
 
 int ddp(fits *a, int level, float coeff, float sigma) {
 	fits fit = { 0 };
+	if (a->orig_bitpix == BYTE_IMG) {
+		siril_log_color_message(_("This process cannot be applied to 8b images\n"), "red");
+		return 1;
+	}
 	if (level < 0 || level > USHRT_MAX) {
 		siril_log_color_message(_("ddp level argument must be [0, 65535]\n"), "green");
 		return 1;
@@ -228,16 +233,12 @@ int ddp(fits *a, int level, float coeff, float sigma) {
 int visu(fits *fit, int low, int high) {
 	if (low < 0 || low > USHRT_MAX || high < 1 || high > USHRT_MAX)
 		return 1;
-	if (single_image_is_loaded() && com.cvport < com.uniq->nb_layers) {
-		com.uniq->layers[com.cvport].hi = high;
-		com.uniq->layers[com.cvport].lo = low;
-	} else if (sequence_is_loaded() && com.cvport < com.seq.nb_layers) {
-		com.seq.layers[com.cvport].hi = high;
-		com.seq.layers[com.cvport].lo = low;
-	} else
+	if (!single_image_is_loaded() && !sequence_is_loaded())
 		return 1;
+	gui.lo = low;
+	gui.hi = high;
 	set_cutoff_sliders_values();
-	redraw(com.cvport, REMAP_ONLY);
+	redraw(REMAP_ALL);
 	redraw_previews();
 	return 0;
 }
@@ -297,10 +298,10 @@ static int off_uchar(fits *fit, float level) {
 	g_assert(fit->naxes[2] <= 3);
 	if (level == 0)
 		return 0;
-	if (level < -UCHAR_MAX)
-		level = -UCHAR_MAX;
-	else if (level > UCHAR_MAX)
-		level = UCHAR_MAX;
+	if (level < -UCHAR_MAX_SINGLE)
+		level = -UCHAR_MAX_SINGLE;
+	else if (level > UCHAR_MAX_SINGLE)
+		level = UCHAR_MAX_SINGLE;
 	size_t i, n = fit->naxes[0] * fit->naxes[1];
 	for (i = 0; i < n; ++i) {
 		for (int layer = 0; layer < fit->naxes[2]; ++layer) {
@@ -318,10 +319,10 @@ static int off_ushort(fits *fit, float level) {
 	g_assert(fit->naxes[2] <= 3);
 	if (level == 0)
 		return 0;
-	if (level < -USHRT_MAX)
-		level = -USHRT_MAX;
-	else if (level > USHRT_MAX)
-		level = USHRT_MAX;
+	if (level < -USHRT_MAX_SINGLE)
+		level = -USHRT_MAX_SINGLE;
+	else if (level > USHRT_MAX_SINGLE)
+		level = USHRT_MAX_SINGLE;
 	size_t i, n = fit->naxes[0] * fit->naxes[1];
 	for (i = 0; i < n; ++i) {
 		for (int layer = 0; layer < fit->naxes[2]; ++layer) {
@@ -391,33 +392,64 @@ void show_FITS_header(fits *fit) {
 }
 
 void compute_grey_flat(fits *fit) {
-	float mean[4];
-	float diag1, diag2, coeff1, coeff2;
-	int config;
+	float coeff1, coeff2;
+	double mean[36] = {0};
+	double green_var[num_filter_patterns];
+	double ch_mean[num_filter_patterns][3];
+	double delta;
+	unsigned int cell, pat, pat_width, pat_cell, ch_n[3];
+	unsigned int guessed_pat = 0;
 
-	/* compute means of 4 channels */
+	/* compute mean of each element in 6x6 blocks */
 	compute_means_from_flat_cfa(fit, mean);
 
 	/* compute coefficients */
 
-	/* looking for green diagonal */
-	diag1 = mean[0] / mean[3];
-	diag2 = mean[1] / mean[2];
+	for (pat = 0; pat < num_filter_patterns; pat++) {
+		green_var[pat] = 0;
+		ch_mean[pat][0] = ch_mean[pat][1] = ch_mean[pat][2] = 0;
+		ch_n[0] = ch_n[1] = ch_n[2] = 0;
+		/* compute width of the (square) CFA pattern */
+		/* added 0.1 in case the result of sqrt is something like 5.999999 and it gets casted to int as 5 */
+		pat_width = (unsigned int) (sqrt(strlen(filter_pattern[pat]))+0.1);
 
-	/* BAYER_FILTER_RGGB
-	 * BAYER_FILTER_BGGR */
-	if (fabs(1.f - diag1) < fabs(1.f - diag2)) {
-		coeff1 = mean[1] / mean[0];
-		coeff2 = mean[2] / mean[3];
-		config = 0;
-	} /* BAYER_FILTER_GBRG
-	 * BAYER_FILTER_GRBG */
-	else {
-		coeff1 = mean[0] / mean[1];
-		coeff2 = mean[3] / mean[2];
-		config = 1;
+		for (cell = 0; cell < 36; cell++) {
+			/* convert 6 x 6 block coordinates to CFA pattern local coordinates */
+			pat_cell = ( cell / 6 % pat_width) * pat_width + cell % pat_width;
+
+			switch(filter_pattern[pat][pat_cell]) {
+				case 'G':
+					delta = mean[cell] - ch_mean[pat][1];
+					ch_n[1]++;
+					ch_mean[pat][1] += delta/ch_n[1];
+					/* we use welford's algortihm to compute the variance */
+					green_var[pat] += delta*(mean[cell]-ch_mean[pat][1]);
+					break;
+				case 'R':
+					delta = mean[cell] - ch_mean[pat][0];
+					ch_n[0]++;
+					ch_mean[pat][0] += delta/ch_n[0];
+					break;
+				case 'B':
+					delta = mean[cell] - ch_mean[pat][2];
+					ch_n[2]++;
+					ch_mean[pat][2] += delta/ch_n[2];
+					break;
+			}
+		}
+		/* we use bessel's correction, so n-1 */
+		green_var[pat] /= (double) (ch_n[1]-1);
+		if (green_var[pat] < green_var[guessed_pat]) {
+			guessed_pat = pat;
+		}
 	}
 
+	siril_debug_print("Guessed pattern: #%d (%s)\n", guessed_pat, filter_pattern[guessed_pat]);
+
+	coeff1 = ch_mean[guessed_pat][0]/ch_mean[guessed_pat][1];
+	coeff2 = ch_mean[guessed_pat][2]/ch_mean[guessed_pat][1];
+	siril_debug_print("coeff1: %.5f, coeff2: %.5f\n", coeff1, coeff2);
+
 	/* applies coefficients to cfa image */
-	equalize_cfa_fit_with_coeffs(fit, coeff1, coeff2, config);
+	equalize_cfa_fit_with_coeffs(fit, coeff1, coeff2, filter_pattern[guessed_pat]);
 }
