@@ -147,7 +147,7 @@ gchar* siril_world_cs_delta_format(SirilWorldCS *world_cs, const gchar *format)
 	int degree = (int) dec;
 	int min = abs((int) ((dec - degree) * 60.0));
 	double sec = (fabs((dec - degree) * 60.0) - min) * 60.0;
-	if (round(sec) >= 60.) {
+	if (sec >= 60.) {
 		sec -= 60.;
 		min += 1;
 	}
@@ -161,7 +161,17 @@ gchar* siril_world_cs_delta_format(SirilWorldCS *world_cs, const gchar *format)
 	if (ptr) { // floating point for second
 		return g_strdup_printf(format, sig, degree, min, sec);
 	}
-	return g_strdup_printf(format, sig, degree, min, (int) round(sec));
+	int new_sec = (int) round(sec);
+	if (new_sec >= 60) {
+		new_sec -= 60;
+		min += 1;
+	}
+	if (min >= 60) {
+		min -= 60;
+		degree += 1;
+	}
+	if (degree >= 360) degree = 0;
+	return g_strdup_printf(format, sig, degree, min, new_sec);
 }
 
 gchar* siril_world_cs_alpha_format(SirilWorldCS *world_cs, const gchar *format) {
@@ -176,7 +186,7 @@ gchar* siril_world_cs_alpha_format(SirilWorldCS *world_cs, const gchar *format)
 	int hour = (int)(ra / 15.0);
 	int min = (int)(((ra / 15.0) - hour) * 60.0);
 	double sec = ((((ra / 15.0) - hour) * 60.0) - min) * 60.0;
-	if (round(sec) >= 60.) {
+	if (sec >= 60.) {
 		sec -= 60.;
 		min += 1;
 	}
@@ -190,7 +200,17 @@ gchar* siril_world_cs_alpha_format(SirilWorldCS *world_cs, const gchar *format)
 	if (ptr) { // floating point for second
 		return g_strdup_printf(format, hour, min, sec);
 	}
-	return g_strdup_printf(format, hour, min, (int) round(sec));
+	int new_sec = (int) round(sec);
+	if (new_sec >= 60) {
+		new_sec -= 60;
+		min += 1;
+	}
+	if (min >= 60) {
+		min -= 60;
+		hour += 1;
+	}
+	if (hour >= 24) hour = 0;
+	return g_strdup_printf(format, hour, min,  new_sec);
 }
 
 void siril_world_cs_get_ra_hour_min_sec(SirilWorldCS *world_cs, int *hour, int *min, double *sec) {
