@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -170,6 +170,12 @@ WORD truncate_to_WORD(int x) {
 	return (WORD)x;
 }
 
+BYTE truncate_to_BYTE(WORD x) {
+	if (x > UCHAR_MAX)
+		return UCHAR_MAX;
+	return (BYTE)x;
+}
+
 /**
  * Clamp an integer value in the interval given by [low, high]
  * @param val value to be checked
@@ -1162,14 +1168,8 @@ char *format_basename(char *root, gboolean can_free) {
  * @return the computed slope
  */
 float compute_slope(WORD *lo, WORD *hi) {
-	if (sequence_is_loaded() && !single_image_is_loaded()) {
-		*hi = com.seq.layers[RLAYER].hi;
-		*lo = com.seq.layers[RLAYER].lo;
-	}
-	else {
-		*hi = com.uniq->layers[RLAYER].hi;
-		*lo = com.uniq->layers[RLAYER].lo;
-	}
+	*lo = gui.lo;
+	*hi = gui.hi;
 	return UCHAR_MAX_SINGLE / (float) (*hi - *lo);
 }
 
@@ -1282,3 +1282,81 @@ gchar* url_cleanup(const gchar *uri_string) {
 
 	return g_string_free(copy, FALSE);
 }
+
+/**
+ * Deblanks a string
+ * @param s string to be deblanked
+ */
+void remove_spaces_from_str(gchar *s) {
+	gchar *d = s;
+	do {
+		while (g_ascii_isspace(*d)) {
+			++d;
+		}
+	} while((*s++ = *d++));
+}
+
+#if !GLIB_CHECK_VERSION(2,68,0)
+/**
+ * g_string_replace:
+ * @string: a #GString
+ * @find: the string to find in @string
+ * @replace: the string to insert in place of @find
+ * @limit: the maximum instances of @find to replace with @replace, or `0` for
+ * no limit
+ *
+ * Replaces the string @find with the string @replace in a #GString up to
+ * @limit times. If the number of instances of @find in the #GString is
+ * less than @limit, all instances are replaced. If the number of
+ * instances is `0`, all instances of @find are replaced.
+ *
+ * If @find is the empty string, since versions 2.69.1 and 2.68.4 the
+ * replacement will be inserted no more than once per possible position
+ * (beginning of string, end of string and between characters). This did
+ * not work correctly in earlier versions.
+ *
+ * Returns: the number of find and replace operations performed.
+ *
+ * Since: 2.68
+ */
+guint
+g_string_replace (GString     *string,
+                  const gchar *find,
+                  const gchar *replace,
+                  guint        limit)
+{
+  gsize f_len, r_len, pos;
+  gchar *cur, *next;
+  gint n = 0;
+
+  g_return_val_if_fail (string != NULL, 0);
+  g_return_val_if_fail (find != NULL, 0);
+  g_return_val_if_fail (replace != NULL, 0);
+
+  f_len = strlen (find);
+  r_len = strlen (replace);
+  cur = string->str;
+
+  while ((next = strstr (cur, find)) != NULL)
+    {
+      pos = next - string->str;
+      g_string_erase (string, pos, f_len);
+      g_string_insert (string, pos, replace);
+      cur = string->str + pos + r_len;
+      n++;
+      /* Only match the empty string once at any given position, to
+       * avoid infinite loops */
+      if (f_len == 0)
+        {
+          if (cur[0] == '\0')
+            break;
+          else
+            cur++;
+        }
+      if (n == limit)
+        break;
+    }
+
+  return n;
+}
+#endif
