@@ -21,7 +21,7 @@ void set_icon_entry(GtkEntry *entry, gchar *string);
 void update_MenuItem();
 void sliders_mode_set_state(sliders_mode);
 display_mode get_display_mode_from_menu();
-int copy_rendering_settings_when_chained(gboolean from_GUI);
+int copy_rendering_settings();
 
 void clear_sampling_setting_box();
 void set_GUI_CAMERA();
@@ -34,7 +34,7 @@ void update_display_fwhm();
 void display_filename();
 void set_precision_switch();
 void set_layers_for_assign();
-void set_layers_for_registration();
+int set_layers_for_registration();
 void show_dialog(const char *text, const char *title, const char *icon);
 void show_txt_and_data_dialog(const char *text, const char *data, const char *title, const char *icon);
 void show_data_dialog(char *text, char *title, gchar *parent, gchar *extra_button);
@@ -42,14 +42,13 @@ GtkWindow *siril_get_active_window();
 void initialize_FITS_name_entries();
 
 void adjust_vport_size_to_image();
-void scrollbars_hadjustment_changed_handler(GtkAdjustment *adjustment, gpointer user_data);
-void scrollbars_vadjustment_changed_handler(GtkAdjustment *adjustment, gpointer user_data);
 void set_output_filename_to_sequence_name();
 void close_tab();
 void activate_tab(int vport);
 
 void update_prepro_interface();
 
+void on_treeview_selection_convert_changed(GtkTreeSelection *treeselection, gpointer user_data);
 void update_statusbar_convert();
 
 void update_spinCPU(int max);
@@ -67,7 +66,6 @@ void set_viewer_mode_widgets_sensitive(gboolean sensitive);
 void on_radiobutton_minmax_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_radiobutton_hilo_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_radiobutton_user_toggled(GtkToggleButton *togglebutton, gpointer user_data);
-void on_checkchain_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 void on_max_entry_changed(GtkEditable *editable, gpointer user_data);
 void on_min_entry_changed(GtkEditable *editable, gpointer user_data);
 
@@ -83,4 +81,9 @@ void on_check_button_pref_bias_bis_toggled(GtkToggleButton *togglebutton, gpoint
 void on_checkbutton_cam_toggled(GtkToggleButton *button, gpointer user_data);
 void on_checkbutton_auto_toggled(GtkToggleButton *button, gpointer user_data);
 
+void on_focal_entry_changed(GtkEditable *editable, gpointer user_data);
+void on_pitchX_entry_changed(GtkEditable *editable, gpointer user_data);
+void on_pitchY_entry_changed(GtkEditable *editable, gpointer user_data);
+void on_combobinning_changed(GtkComboBox *box, gpointer user_data);
+
 #endif
