@@ -185,14 +185,13 @@ gnuplot_ctrl * gnuplot_init(void)
 
 void gnuplot_close(gnuplot_ctrl * handle)
 {
-    int     i ;
 
     if (pclose(handle->gnucmd) == -1) {
         fprintf(stderr, "problem closing communication to gnuplot\n") ;
         return ;
     }
     if (handle->ntmp) {
-        for (i=0 ; i<handle->ntmp ; i++) {
+		for (int i = 0; i < handle->ntmp; i++) {
             remove(handle->tmp_filename_tbl[i]) ;
             free(handle->tmp_filename_tbl[i]);
             handle->tmp_filename_tbl[i] = NULL;
@@ -378,9 +377,8 @@ void gnuplot_reverse_yaxis(gnuplot_ctrl * h)
 
 void gnuplot_resetplot(gnuplot_ctrl * h)
 {
-    int     i ;
     if (h->ntmp) {
-        for (i=0 ; i<h->ntmp ; i++) {
+		for (int i = 0; i < h->ntmp; i++) {
             remove(h->tmp_filename_tbl[i]) ;
             free(h->tmp_filename_tbl[i]);
             h->tmp_filename_tbl[i] = NULL;
