@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -34,6 +34,7 @@
 #include "gui/progress_and_log.h"
 #include "gui/dialogs.h"
 #include "gui/siril_preview.h"
+#include "gui/registration_preview.h"
 #include "core/undo.h"
 
 #include "histogram.h"
@@ -98,18 +99,18 @@ static void histo_startup() {
 }
 
 static void histo_close(gboolean revert) {
-	int i;
 	if (revert) {
 		set_cursor_waiting(TRUE);
 
-		for (i = 0; i < gfit.naxes[2]; i++) {
+		for (int i = 0; i < gfit.naxes[2]; i++) {
 			set_histogram(hist_backup[i], i);
 			hist_backup[i] = NULL;
 		}
-		copy_backup_to_gfit();
-		adjust_cutoff_from_updated_gfit();
-		redraw(com.cvport, REMAP_ALL);
-		redraw_previews();
+		if (!copy_backup_to_gfit()) {
+			adjust_cutoff_from_updated_gfit();
+			redraw(REMAP_ALL);
+			redraw_previews();
+		}
 		set_cursor_waiting(FALSE);
 	}
 
@@ -126,7 +127,7 @@ static void histo_recompute() {
 	// com.layers_hist should be good, update_histo_mtf() is always called before
 
 	adjust_cutoff_from_updated_gfit();
-	redraw(com.cvport, REMAP_ALL);
+	redraw(REMAP_ALL);
 	redraw_previews();
 }
 
@@ -250,7 +251,7 @@ static void set_histo_toggles_names() {
 static double get_histoZoomValueH() {
 	static GtkAdjustment *histoAdjZoomH = NULL;
 	if (!histoAdjZoomH)
-		histoAdjZoomH = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "histoAdjZoomH"));
+		histoAdjZoomH = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "histoAdjZoomH"));
 
 	return gtk_adjustment_get_value(histoAdjZoomH);
 }
@@ -258,7 +259,7 @@ static double get_histoZoomValueH() {
 static double get_histoZoomValueV() {
 	static GtkAdjustment *histoAdjZoomV = NULL;
 	if (!histoAdjZoomV)
-		histoAdjZoomV = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "histoAdjZoomV"));
+		histoAdjZoomV = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "histoAdjZoomV"));
 
 	return gtk_adjustment_get_value(histoAdjZoomV);
 }
@@ -735,7 +736,9 @@ float findMidtonesBalance(fits *fit, float *shadows, float *highlights) {
 		stat[i] = statistics(NULL, -1, fit, i, NULL, STATS_BASIC | STATS_MAD, TRUE);
 		if (!stat[i]) {
 			siril_log_message(_("Error: statistics computation failed.\n"));
-			return 0.f;
+			*shadows = 0.0f;
+			*highlights = 1.0f;
+			return 0.2f;	// better than linear, but not too risky
 		}
 
 		if (stat[i]->median / stat[i]->normValue > 0.5)
@@ -864,7 +867,8 @@ void on_button_histo_apply_clicked(GtkButton *button, gpointer user_data) {
 		return;
 	}
 
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(lookup_widget("checkMTFSeq")))
+	GtkToggleButton *seq_button = GTK_TOGGLE_BUTTON(lookup_widget("checkMTFSeq"));
+	if (gtk_toggle_button_get_active(seq_button)
 			&& sequence_is_loaded()) {
 		/* Apply to the whole sequence */
 		struct mtf_data *args = malloc(sizeof(struct mtf_data));
@@ -885,6 +889,7 @@ void on_button_histo_apply_clicked(GtkButton *button, gpointer user_data) {
 		siril_close_dialog("histogram_dialog");
 
 		/* apply the process */
+		gtk_toggle_button_set_active(seq_button, FALSE);
 		apply_mtf_to_sequence(args);
 
 	} else {
@@ -917,8 +922,8 @@ void apply_histo_cancel() {
 void on_histoZoom100_clicked(GtkButton *button, gpointer user_data) {
 	GtkAdjustment *histoAdjZoomH, *histoAdjZoomV;
 
-	histoAdjZoomH = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "histoAdjZoomH"));
-	histoAdjZoomV = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "histoAdjZoomV"));
+	histoAdjZoomH = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "histoAdjZoomH"));
+	histoAdjZoomV = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "histoAdjZoomV"));
 
 	gtk_adjustment_set_value(histoAdjZoomH, 1.0);
 	gtk_adjustment_set_value(histoAdjZoomV, 1.0);
