@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -38,14 +38,16 @@
 #include "algos/statistics.h"
 #include "algos/photometry.h"
 #include "algos/PSF.h"
-#include "algos/plateSolver.h"
+#include "algos/astrometry_solver.h"
 #include "algos/star_finder.h"
 #include "gui/image_display.h"
+#include "gui/image_interactions.h"
 #include "gui/message_dialog.h"
 #include "gui/utils.h"
 #include "gui/progress_and_log.h"
 #include "gui/histogram.h"
 #include "gui/dialogs.h"
+#include "gui/registration_preview.h"
 
 #include "photometric_cc.h"
 
@@ -54,7 +56,7 @@ enum {
 };
 
 static void start_photometric_cc() {
-	struct plate_solver_data *args = malloc(sizeof(struct plate_solver_data));
+	struct astrometry_data *args = malloc(sizeof(struct astrometry_data));
 
 	args->for_photometry_cc = TRUE;
 	if (!fill_plate_solver_structure(args)) {
@@ -63,7 +65,7 @@ static void start_photometric_cc() {
 	}
 }
 
-static void read_photometry_cc_file(GInputStream *stream, fitted_PSF **stars, int *nb_stars) {
+static void read_photometry_cc_file(GInputStream *stream, psf_star **stars, int *nb_stars) {
 	gchar *line;
 	int i = 0;
 
@@ -71,7 +73,7 @@ static void read_photometry_cc_file(GInputStream *stream, fitted_PSF **stars, in
 	while ((line = g_data_input_stream_read_line_utf8(data_input, NULL,
 				NULL, NULL))) {
 		int tmp;
-		fitted_PSF *star = malloc(sizeof(fitted_PSF));
+		psf_star *star = new_psf_star();
 
 		sscanf(line, "%d %lf %lf %lf\n", &tmp, &(star->xpos), &(star->ypos), &(star->BV));
 
@@ -126,7 +128,7 @@ static void bv2rgb(float *r, float *g, float *b, float bv) { // RGB <0,1> <- BV
 	}
 }
 
-static int make_selection_around_a_star(fitted_PSF *stars, rectangle *area, fits *fit) {
+static int make_selection_around_a_star(psf_star *stars, rectangle *area, fits *fit) {
 	/* make a selection around the star */
 	area->x = round_to_int(stars->xpos - com.pref.phot_set.outer);
 	area->y = round_to_int(stars->ypos - com.pref.phot_set.outer);
@@ -176,26 +178,6 @@ static float Qn0(const float sorted_data[], const size_t stride, const size_t n)
 	return Qn;
 }
 
-static float siril_stats_trmean_from_sorted_data(const float trim,
-		const float sorted_data[], const size_t stride, const size_t size) {
-	if (trim >= 0.5f) {
-		return (float) gsl_stats_float_median_from_sorted_data(sorted_data, stride, size);
-	} else {
-		size_t ilow = (size_t) floorf(trim * size);
-		size_t ihigh = size - ilow - 1;
-		float mean = 0.f;
-		float k = 0.f;
-
-		/* compute mean of middle samples in [ilow,ihigh] */
-		for (size_t i = ilow; i <= ihigh; ++i) {
-			float delta = sorted_data[i * stride] - mean;
-			k += 1.f;
-			mean += delta / k;
-		}
-		return mean;
-	}
-}
-
 static float siril_stats_robust_mean(const float sorted_data[],
 		const size_t stride, const size_t size) {
 	float mx = (float) gsl_stats_float_median_from_sorted_data(sorted_data, stride, size);
@@ -219,8 +201,7 @@ static float siril_stats_robust_mean(const float sorted_data[],
 	}
 	/* not enough stars, try something anyway */
 	if (j < 5) {
-		mean = (float) siril_stats_trmean_from_sorted_data(0.3f, sorted_data, stride,
-				size);
+		mean = siril_stats_trmean_from_sorted_data(0.3f, sorted_data, stride, size);
 	} else {
 		mean = (float) gsl_stats_float_mean(x, stride, j);
 	}
@@ -228,7 +209,7 @@ static float siril_stats_robust_mean(const float sorted_data[],
 	return mean;
 }
 
-static int get_white_balance_coeff(fitted_PSF **stars, int nb_stars, fits *fit, float kw[], int n_channel) {
+static int get_white_balance_coeff(psf_star **stars, int nb_stars, fits *fit, float kw[], int n_channel) {
 	int i = 0, ngood = 0;
 	gboolean no_phot = FALSE;
 	int progress = 0;
@@ -249,7 +230,11 @@ static int get_white_balance_coeff(fitted_PSF **stars, int nb_stars, fits *fit,
 		data[BLUE][k] = FLT_MAX;
 	}
 
-	siril_log_message(_("Applying aperture photometry to %d stars.\n"), nb_stars);
+	gchar *str = ngettext("Applying aperture photometry to %d star.\n", "Applying aperture photometry to %d stars.\n", nb_stars);
+	str = g_strdup_printf(str, nb_stars);
+	siril_log_message(str);
+	g_free(str);
+
 	set_progress_bar_data(_("Photometry color calibration in progress..."), PROGRESS_RESET);
 
 	while (stars[i]) {
@@ -266,13 +251,13 @@ static int get_white_balance_coeff(fitted_PSF **stars, int nb_stars, fits *fit,
 		}
 
 		for (int chan = 0; chan < 3; chan ++) {
-			fitted_PSF *photometry = psf_get_minimisation(fit, chan, &area, TRUE, FALSE, TRUE);
+			psf_star *photometry = psf_get_minimisation(fit, chan, &area, TRUE, com.pref.phot_set.force_radius, FALSE, TRUE);
 			if (!photometry || !photometry->phot_is_valid) {
 				no_phot = TRUE;
 				break;
 			}
 			flux[chan] = powf(10.f, -0.4f * (float) photometry->mag);
-			free(photometry);
+			free_psf(photometry);
 		}
 		if (no_phot) {
 			i++;
@@ -299,7 +284,7 @@ static int get_white_balance_coeff(fitted_PSF **stars, int nb_stars, fits *fit,
 		ngood++;
 	}
 	int excl = nb_stars - ngood;
-	gchar *str = ngettext("%d star excluded from the calculation\n", "%d stars excluded from the calculation\n", excl);
+	str = ngettext("%d star excluded from the calculation\n", "%d stars excluded from the calculation\n", excl);
 	str = g_strdup_printf(str, excl);
 	siril_log_message(str);
 	g_free(str);
@@ -446,7 +431,9 @@ static gboolean end_photometric_cc(gpointer p) {
 	g_object_unref(args->bv_stream);
 	free(args);
 
-	redraw(com.cvport, REMAP_ALL);
+	invalidate_gfit_histogram();
+	update_gfit_histogram_if_needed();
+	redraw(REMAP_ALL);
 	redraw_previews();
 	
 	set_cursor_waiting(FALSE);
@@ -551,10 +538,10 @@ void initialize_photometric_cc_dialog() {
 
 	parent = GTK_WINDOW(lookup_widget("ImagePlateSolver_Dial"));
 
-	selection_cc_black_adjustment[0] = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment_cc_bkg_x"));
-	selection_cc_black_adjustment[1] = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment_cc_bkg_y"));
-	selection_cc_black_adjustment[2] = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment_cc_bkg_w"));
-	selection_cc_black_adjustment[3] = GTK_ADJUSTMENT(gtk_builder_get_object(builder, "adjustment_cc_bkg_h"));
+	selection_cc_black_adjustment[0] = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "adjustment_cc_bkg_x"));
+	selection_cc_black_adjustment[1] = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "adjustment_cc_bkg_y"));
+	selection_cc_black_adjustment[2] = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "adjustment_cc_bkg_w"));
+	selection_cc_black_adjustment[3] = GTK_ADJUSTMENT(gtk_builder_get_object(gui.builder, "adjustment_cc_bkg_h"));
 
 	gtk_widget_set_visible(button_ips_ok, FALSE);
 	gtk_widget_set_visible(button_cc_ok, TRUE);
@@ -580,7 +567,7 @@ void initialize_photometric_cc_dialog() {
 }
 
 int apply_photometric_cc() {
-	fitted_PSF **stars;
+	psf_star **stars;
 	GtkComboBox *norm_box;
 	GtkToggleButton *auto_bkg;
 	GError *error = NULL;
@@ -588,7 +575,7 @@ int apply_photometric_cc() {
 	norm_box = GTK_COMBO_BOX(lookup_widget("combo_box_cc_norm"));
 	auto_bkg = GTK_TOGGLE_BUTTON(lookup_widget("button_cc_bkg_auto"));
 
-	undo_save_state(&gfit, _("Photometric CC"));
+
 	invalidate_stats_from_fit(&gfit);
 	invalidate_gfit_histogram();
 
@@ -606,7 +593,7 @@ int apply_photometric_cc() {
 		return 1;
 	}
 
-	stars = malloc((MAX_STARS + 1) * sizeof(fitted_PSF *));
+	stars = new_fitted_stars(MAX_STARS);
 	if (stars == NULL) {
 		PRINT_ALLOC_ERR;
 		set_cursor_waiting(FALSE);
@@ -687,4 +674,6 @@ void on_button_cc_bkg_selection_clicked(GtkButton *button, gpointer user_data) {
 	gtk_spin_button_set_value(selection_cc_bkg_value[1], com.selection.y);
 	gtk_spin_button_set_value(selection_cc_bkg_value[2], com.selection.w);
 	gtk_spin_button_set_value(selection_cc_bkg_value[3], com.selection.h);
+
+	delete_selected_area(); // needed because we don't want the selection being used for astrometry
 }
