@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -34,14 +34,18 @@
 #include "core/siril_date.h"
 #include "core/OS_utils.h"
 #include "core/processing.h"
+#include "core/sleef.h"
 #include "gui/utils.h"
 #include "gui/image_display.h"
+#include "gui/dialogs.h"
 #include "gui/message_dialog.h"
 #include "gui/progress_and_log.h"
 #include "gui/sequence_list.h"
+#include "registration/registration.h"
 #include "kplot.h"
 #include "algos/PSF.h"
 #include "io/ser.h"
+#include "io/sequence.h"
 #include "gui/gnuplot_i/gnuplot_i.h"
 #include "gui/PSF_list.h"
 
@@ -49,15 +53,19 @@
 
 static GtkWidget *drawingPlot = NULL, *sourceCombo = NULL, *combo = NULL,
 		*varCurve = NULL, *buttonClearAll = NULL,
-		*buttonClearLatest = NULL, *arcsec = NULL, *julianw = NULL;
+		*buttonClearLatest = NULL, *arcsec = NULL, *julianw = NULL,
+		*comboX = NULL, *layer_selector = NULL;
 static pldata *plot_data;
-static struct kpair ref;
-static gboolean is_fwhm = FALSE, use_photometry = FALSE, requires_color_update =
-		FALSE;
+static struct kpair ref, curr;
+static gboolean use_photometry = FALSE, requires_seqlist_update = FALSE;
 static char *ylabel = NULL;
 static gchar *xlabel = NULL;
-static enum photmetry_source selected_source = ROUNDNESS;
+static enum photometry_source photometry_selected_source = FWHM;
+static enum registration_source registration_selected_source = r_FWHM;
+static enum registration_source X_selected_source = r_FRAME;
 static int julian0 = 0;
+static int reglayer = 0;
+static gboolean is_fwhm = TRUE;
 static gnuplot_ctrl *gplot = NULL;
 static gboolean is_arcsec = FALSE;
 static gboolean force_Julian = FALSE;
@@ -65,6 +73,31 @@ static gboolean force_Julian = FALSE;
 static void update_ylabel();
 static void set_colors(struct kplotcfg *cfg);
 static void free_colors(struct kplotcfg *cfg);
+void on_JulianPhotometry_toggled(GtkToggleButton *button, gpointer user_data);
+void on_plotCombo_changed(GtkComboBox *box, gpointer user_data);
+void on_plotComboX_changed(GtkComboBox *box, gpointer user_data);
+
+
+static const gchar *photometry_labels[] = {
+		N_("FWHM"),
+		N_("Roundness"),
+		N_("Amplitude"),
+		N_("Magnitude"),
+		N_("Background"),
+		N_("X Position"),
+		N_("Y Position"),
+		N_("SNR")
+};
+
+static const gchar *registration_labels[] = {
+		N_("FWHM"),
+		N_("Roundness"),
+		N_("wFWHM"),
+		N_("Quality"),
+		N_("X Position"),
+		N_("Y Position"),
+		N_("Frame"),
+};
 
 static pldata *alloc_plot_data(int size) {
 	pldata *plot = calloc(1, sizeof(pldata));
@@ -110,26 +143,101 @@ static pldata *alloc_plot_data(int size) {
 static void build_registration_dataset(sequence *seq, int layer, int ref_image,
 		pldata *plot) {
 	int i, j;
+	double fwhm;
+	curr.x = -1.0;
+	curr.y = -1.0;
 
 	for (i = 0, j = 0; i < plot->nb; i++) {
 		if (!seq->imgparam[i].incl)
 			continue;
-		plot->data[j].x = (double) i + 1;
-		plot->data[j].y = is_fwhm ?	seq->regparam[layer][i].fwhm :
-						seq->regparam[layer][i].quality;
-		plot->frame[j] =  plot->data[j].x;
+		switch (X_selected_source) {
+			case r_ROUNDNESS:
+				plot->data[j].x = seq->regparam[layer][i].roundness;
+				break;
+			case r_FWHM:
+				if (is_arcsec) {
+					double bin = gfit.unbinned ? (double) gfit.binning_x : 1.0;
+					convert_single_fwhm_to_arcsec_if_possible(seq->regparam[layer][i].fwhm, bin, (double) gfit.pixel_size_x, gfit.focal_length, &fwhm);
+				} else {
+					fwhm = seq->regparam[layer][i].fwhm;
+				}
+				plot->data[j].x = fwhm;
+				break;
+			case r_X_POSITION:
+				plot->data[j].x = seq->regparam[layer][i].shiftx;
+				break;
+			case r_Y_POSITION:
+				plot->data[j].x = seq->regparam[layer][i].shifty;
+				break;
+			case r_WFWHM:
+				if (is_arcsec) {
+					double bin = gfit.unbinned ? (double) gfit.binning_x : 1.0;
+					convert_single_fwhm_to_arcsec_if_possible(seq->regparam[layer][i].weighted_fwhm, bin, (double) gfit.pixel_size_x, gfit.focal_length, &fwhm);
+				} else {
+					fwhm = seq->regparam[layer][i].weighted_fwhm;
+				}
+				plot->data[j].x = fwhm;
+				break;
+			case r_QUALITY:
+				plot->data[j].x = seq->regparam[layer][i].quality;
+				break;
+			case r_FRAME:
+				plot->data[j].x = (double) i + 1;
+				break;
+			default:
+				break;
+		}
+		plot->data[j].x = (isnan(plot->data[j].x)) ? 0.0 : plot->data[j].x;
+		switch (registration_selected_source) {
+			case r_ROUNDNESS:
+				plot->data[j].y = seq->regparam[layer][i].roundness;
+				break;
+			case r_FWHM:
+				if (is_arcsec) {
+					double bin = gfit.unbinned ? (double) gfit.binning_x : 1.0;
+					convert_single_fwhm_to_arcsec_if_possible(seq->regparam[layer][i].fwhm, bin, (double) gfit.pixel_size_x, gfit.focal_length, &fwhm);
+				} else {
+					fwhm = seq->regparam[layer][i].fwhm;
+				}
+				plot->data[j].y = fwhm;
+				break;
+			case r_X_POSITION:
+				plot->data[j].y = seq->regparam[layer][i].shiftx;
+				break;
+			case r_Y_POSITION:
+				plot->data[j].y = seq->regparam[layer][i].shifty;
+				break;
+			case r_WFWHM:
+				if (is_arcsec) {
+					double bin = gfit.unbinned ? (double) gfit.binning_x : 1.0;
+					convert_single_fwhm_to_arcsec_if_possible(seq->regparam[layer][i].weighted_fwhm, bin, (double) gfit.pixel_size_x, gfit.focal_length, &fwhm);
+				} else {
+					fwhm = seq->regparam[layer][i].weighted_fwhm;
+				}
+				plot->data[j].y = fwhm;
+				break;
+			case r_QUALITY:
+				plot->data[j].y = seq->regparam[layer][i].quality;
+				break;
+			default:
+				break;
+		}
+		plot->data[j].y = (isnan(plot->data[j].y)) ? 0.0 : plot->data[j].y;
+		plot->frame[j] =  (double) i + 1;
+		if (i == ref_image) {
+			ref.x = plot->data[j].x;
+			ref.y = plot->data[j].y;
+		}
+		if ((i == seq->current) & com.seq.imgparam[i].incl) {
+			curr.x = plot->data[j].x;
+			curr.y = plot->data[j].y;
+		}
 		j++;
 	}
 	plot->nb = j;
-
-	ref.x = (double) ref_image + 1;
-	ref.y = is_fwhm ?
-			seq->regparam[layer][ref_image].fwhm :
-			seq->regparam[layer][ref_image].quality;
-
 }
 
-static void set_x_values(sequence *seq, pldata *plot, int i, int j) {
+static void set_x_photometry_values(sequence *seq, pldata *plot, int i, int j) {
 	if (seq->imgparam[i].date_obs) {
 		double julian;
 		GDateTime *tsi = g_date_time_ref(seq->imgparam[i].date_obs);
@@ -163,9 +271,11 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 	int i, j;
 	double offset = -1001.0;
 	double fwhm;
-	fitted_PSF **psfs = seq->photometry[dataset], *ref_psf;
+	psf_star **psfs = seq->photometry[dataset], *ref_psf;
 	if (seq->reference_star >= 0 && !seq->photometry[seq->reference_star])
 		seq->reference_star = -1;
+	curr.x = -1.0;
+	curr.y = -1.0;
 
 	for (i = 0, j = 0; i < size; i++) {
 		if (!seq->imgparam[i].incl || !psfs[i])
@@ -189,9 +299,9 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 				xlabel = g_strdup(_("Frames"));
 			}
 		}
-		set_x_values(seq, plot, i, j);
+		set_x_photometry_values(seq, plot, i, j);
 
-		switch (selected_source) {
+		switch (photometry_selected_source) {
 			case ROUNDNESS:
 				plot->data[j].y = psfs[i]->fwhmy / psfs[i]->fwhmx;
 				break;
@@ -234,6 +344,11 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 			case Y_POSITION:
 				plot->data[j].y = psfs[i]->ypos;
 				break;
+			case SNR:
+				plot->data[j].y = psfs[i]->SNR;
+				break;
+			default:
+				break;
 		}
 
 		/* we'll just take the reference image point from the last data set rendered */
@@ -241,6 +356,10 @@ static void build_photometry_dataset(sequence *seq, int dataset, int size,
 			ref.x = plot->data[j].x;
 			ref.y = plot->data[j].y;
 		}
+		if ((i == seq->current) & com.seq.imgparam[i].incl) {
+			curr.x = plot->data[j].x;
+			curr.y = plot->data[j].y;
+		}
 		j++;
 	}
 	plot->nb = j;
@@ -298,8 +417,6 @@ static int lightCurve(pldata *plot, sequence *seq, gchar *filename) {
 				"trying to plot a graph of a variable star.\n"));
 
 		siril_message_dialog( GTK_MESSAGE_WARNING, _("Gnuplot is unavailable"), msg);
-
-		return -1;
 	}
 
 	/* get number of data */
@@ -511,60 +628,173 @@ static void free_plot_data() {
 	plot_data = NULL;
 	julian0 = 0;
 	if (xlabel) {
-		g_free(xlabel);
 		xlabel = NULL;
 	}
 }
+static void set_sensitive(GtkCellLayout *cell_layout,
+			GtkCellRenderer *cell,
+			GtkTreeModel *tree_model,
+			GtkTreeIter *iter,
+			gpointer data) {
+	gboolean sensitive = TRUE;
 
-void on_plotSourceCombo_changed(GtkComboBox *box, gpointer user_data) {
-	use_photometry = gtk_combo_box_get_active(GTK_COMBO_BOX(box));
-	gtk_widget_set_visible(combo, use_photometry);
-	gtk_widget_set_visible(varCurve, use_photometry);
-	gtk_widget_set_visible(arcsec, use_photometry);
-	gtk_widget_set_visible(julianw, use_photometry);
-	drawPlot();
-}
-
-void reset_plot() {
-	free_plot_data();
-	if (sourceCombo) {
-		gtk_combo_box_set_active(GTK_COMBO_BOX(sourceCombo), 0);
-		gtk_widget_set_visible(sourceCombo, FALSE);
-		gtk_widget_set_visible(combo, FALSE);
-		gtk_widget_set_visible(varCurve, FALSE);
-		gtk_widget_set_visible(arcsec, FALSE);
-		gtk_widget_set_visible(julianw, FALSE);
-		gtk_widget_set_sensitive(buttonClearLatest, FALSE);
-		gtk_widget_set_sensitive(buttonClearAll, FALSE);
+	if (!use_photometry) {
+		GtkTreePath* path = gtk_tree_model_get_path (tree_model, iter);
+		if (!path) return;
+		gint *index = gtk_tree_path_get_indices(path); // search by index to avoid translation problems
+		if (index) {
+			if (!is_fwhm) {
+				sensitive = ((index[0] == r_FRAME) || (index[0] == r_QUALITY) || (index[0] == r_X_POSITION) || (index[0] == r_Y_POSITION));
+			} else {
+				sensitive = ((index[0] == r_FRAME) || (index[0] == r_FWHM) || (index[0] == r_WFWHM) || (index[0] == r_ROUNDNESS));
+			}
+		}
 	}
+	g_object_set(cell, "sensitive", sensitive, NULL);
 }
 
-static int compare(const void *a, const void *b) {
-    struct kpair datax_a = * ((struct kpair *) a);
-    struct kpair datax_b = * ((struct kpair *) b);
-
-    if (datax_a.x > datax_b.x) {
-        return 1;
-    } else if (datax_a.x < datax_b.x) {
-        return -1;
-    } else
-        return 0;
-}
-
-void drawPlot() {
-	int i, ref_image, layer = 0;
-	sequence *seq;
-
+static void fill_plot_statics() {
 	if (drawingPlot == NULL) {
 		drawingPlot = lookup_widget("DrawingPlot");
 		combo = lookup_widget("plotCombo");
+		comboX = lookup_widget("plotComboX");
 		varCurve = lookup_widget("varCurvePhotometry");
 		arcsec = lookup_widget("arcsecPhotometry");
 		julianw = lookup_widget("JulianPhotometry");
 		sourceCombo = lookup_widget("plotSourceCombo");
 		buttonClearAll = lookup_widget("clearAllPhotometry");
 		buttonClearLatest = lookup_widget("clearLastPhotometry");
+		layer_selector = lookup_widget("seqlist_dialog_combo");
 	}
+}
+
+static void validate_combos() {
+	fill_plot_statics();
+	use_photometry = gtk_combo_box_get_active(GTK_COMBO_BOX(sourceCombo));
+	if (!use_photometry) {
+		reglayer = gtk_combo_box_get_active(GTK_COMBO_BOX(layer_selector));
+		if (!(com.seq.regparam) || !(com.seq.regparam[reglayer]))
+			reglayer = get_registration_layer(&com.seq);
+	}
+	gtk_widget_set_visible(varCurve, use_photometry);
+	g_signal_handlers_block_by_func(julianw, on_JulianPhotometry_toggled, NULL);
+	gtk_widget_set_visible(julianw, use_photometry);
+	g_signal_handlers_unblock_by_func(julianw, on_JulianPhotometry_toggled, NULL);
+
+	g_signal_handlers_block_by_func(combo, on_plotCombo_changed, NULL);
+	g_signal_handlers_block_by_func(comboX, on_plotComboX_changed, NULL);
+	gtk_combo_box_text_remove_all(GTK_COMBO_BOX_TEXT(combo));
+	int i = 0;
+	if (use_photometry) {
+		while (i < (G_N_ELEMENTS(photometry_labels))) {
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _(photometry_labels[i]));
+			i++;
+		}
+		gtk_combo_box_set_active(GTK_COMBO_BOX(comboX), r_FRAME);
+		X_selected_source = r_FRAME;
+		gtk_widget_set_sensitive(comboX, FALSE);
+	} else {
+		while (i < (G_N_ELEMENTS(registration_labels)) - 1) { // do not write 'Frame' as possible Y value
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _(registration_labels[i]));
+			i++;
+		}
+		gtk_combo_box_set_active(GTK_COMBO_BOX(sourceCombo), 0);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(comboX), X_selected_source);
+		gtk_widget_set_sensitive(comboX, TRUE);
+		if ((!is_fwhm) && registration_selected_source < r_QUALITY) {
+			registration_selected_source = r_QUALITY;
+		}
+		if ((is_fwhm) && registration_selected_source > r_WFWHM) {
+			registration_selected_source = r_FWHM;
+		}
+	}
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo), renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo), renderer, "text", 0, NULL);
+	gtk_cell_layout_set_cell_data_func(GTK_CELL_LAYOUT(combo), renderer, set_sensitive, NULL, NULL);
+
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), (use_photometry) ? photometry_selected_source : registration_selected_source);
+
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(comboX));
+	GtkCellRenderer *rendererX = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(comboX), rendererX, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(comboX), rendererX, "text", 0, NULL);
+	gtk_cell_layout_set_cell_data_func(GTK_CELL_LAYOUT(comboX), rendererX, set_sensitive, NULL, NULL);
+
+	g_signal_handlers_unblock_by_func(combo, on_plotCombo_changed, NULL);
+	g_signal_handlers_unblock_by_func(comboX, on_plotComboX_changed, NULL);
+}
+
+void on_plotSourceCombo_changed(GtkComboBox *box, gpointer user_data) {
+	validate_combos();
+	requires_seqlist_update = TRUE;
+	drawPlot();
+}
+
+void reset_plot() {
+	free_plot_data();
+	int layer;
+	if (sourceCombo) {
+		gtk_combo_box_set_active(GTK_COMBO_BOX(sourceCombo), 0);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(combo), registration_selected_source); //remove?
+		gtk_combo_box_set_active(GTK_COMBO_BOX(comboX), r_FRAME);
+		gtk_widget_set_sensitive(comboX, TRUE);
+		gtk_widget_set_sensitive(sourceCombo, FALSE);
+		gtk_widget_set_visible(varCurve, FALSE);
+		gtk_widget_set_visible(julianw, FALSE);
+		gtk_widget_set_sensitive(buttonClearLatest, FALSE);
+		gtk_widget_set_sensitive(buttonClearAll, FALSE);
+		layer = get_registration_layer(&com.seq);
+		update_seqlist(layer);
+	}
+}
+
+static int compare(const void *a, const void *b) {
+	struct kpair datax_a = * ((struct kpair *) a);
+	struct kpair datax_b = * ((struct kpair *) b);
+
+	if (datax_a.x > datax_b.x) {
+		return 1;
+	} else if (datax_a.x < datax_b.x) {
+		return -1;
+	} else
+		return 0;
+}
+
+static int comparey(const void *a, const void *b) {
+	struct kpair datax_a = * ((struct kpair *) a);
+	struct kpair datax_b = * ((struct kpair *) b);
+
+	if (datax_a.y == 0.) return 1; // push zeros at the back
+	if (datax_b.y == 0.) return -1; // push zeros at the back
+	if (datax_a.y > datax_b.y) {
+		return 1;
+	} else if (datax_a.y < datax_b.y) {
+		return -1;
+	} else
+		return 0;
+}
+
+static int comparey_desc(const void *a, const void *b) {
+	struct kpair datax_a = * ((struct kpair *) b);
+	struct kpair datax_b = * ((struct kpair *) a);
+
+	if (datax_a.y == 0.) return -1; // push zeros at the back
+	if (datax_b.y == 0.) return 1; // push zeros at the back
+	if (datax_a.y > datax_b.y) {
+		return 1;
+	} else if (datax_a.y < datax_b.y) {
+		return -1;
+	} else
+		return 0;
+}
+
+void drawPlot() {
+	int ref_image;
+	sequence *seq;
+
+	validate_combos();
 
 	seq = &com.seq;
 	if (plot_data)
@@ -574,16 +804,28 @@ void drawPlot() {
 		ref_image = 0;
 	else ref_image = seq->reference_image;
 
+	gboolean arcsec_is_ok = (gfit.focal_length > 0.0 && gfit.pixel_size_x > 0.f
+		&& gfit.pixel_size_y > 0.f && gfit.binning_x > 0
+		&& gfit.binning_y > 0);
+	int current_selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
+	if (!arcsec_is_ok) {
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(arcsec), FALSE);
+		is_arcsec = FALSE;
+	}
+
 	if (use_photometry) {
 		// photometry data display
 		pldata *plot;
+		gtk_widget_set_visible(arcsec, ((current_selected_source == FWHM) && arcsec_is_ok));
 		update_ylabel();
 		ref.x = -1.0;
 		ref.y = -1.0;
+		curr.x = -1.0;
+		curr.y = -1.0;
 
 		plot = alloc_plot_data(seq->number);
 		plot_data = plot;
-		for (i = 0; i < MAX_SEQPSF && seq->photometry[i]; i++) {
+		for (int i = 0; i < MAX_SEQPSF && seq->photometry[i]; i++) {
 			if (i > 0) {
 				plot->next = alloc_plot_data(seq->number);
 				plot = plot->next;
@@ -592,33 +834,29 @@ void drawPlot() {
 			build_photometry_dataset(seq, i, seq->number, ref_image, plot);
 			qsort(plot->data, plot->nb, sizeof(struct kpair), compare);
 		}
+		if (requires_seqlist_update) { // update seq list if combo or arcsec changed
+			update_seqlist(reglayer); 
+			requires_seqlist_update = FALSE;
+		}
 	} else {
 		// registration data display
 		if (!(seq->regparam))
 			return;
 
-		for (i = 0; i < seq->nb_layers; i++) {
-			if (com.seq.regparam[i]) {
-				layer = i;
-				break;
-			}
-		}
-		if ((!seq->regparam[layer]))
+		if ((!seq->regparam[reglayer]) || reglayer < 0)
 			return;
 
-		if (seq->regparam[layer][ref_image].fwhm > 0.0f) {
-			is_fwhm = TRUE;
-			ylabel = _("FWHM");
-		} else if (seq->regparam[layer][ref_image].quality > 0.0) {
-			is_fwhm = FALSE;
-			ylabel = _("Quality");
-		} else
-			return;
+		is_fwhm = (seq->regparam[reglayer][ref_image].fwhm > 0.0f) ? TRUE : FALSE;
+		gtk_widget_set_visible(arcsec, ((current_selected_source == r_FWHM) || (current_selected_source == r_WFWHM) || (X_selected_source == r_FWHM) || (X_selected_source == r_WFWHM)) && arcsec_is_ok);
 
+		update_ylabel();
 		/* building data array */
 		plot_data = alloc_plot_data(seq->number);
-
-		build_registration_dataset(seq, layer, ref_image, plot_data);
+		build_registration_dataset(seq, reglayer, ref_image, plot_data);
+		if (requires_seqlist_update) { // update seq list if combo or arcsec changed
+			update_seqlist(reglayer);
+			requires_seqlist_update = FALSE;
+		}
 	}
 	gtk_widget_set_sensitive(julianw, julian0);
 	gtk_widget_queue_draw(drawingPlot);
@@ -659,6 +897,12 @@ static void save_dialog(const gchar *format, int (export_function)(pldata *, seq
 }
 
 void on_ButtonSaveCSV_clicked(GtkButton *button, gpointer user_data) {
+	/* TODO: probably need to set export CSV button sensitivity
+	but this avoids a crash for now */
+	if(!plot_data) {
+		fprintf(stderr, "exportCSV: Nothing to export\n");
+		return;
+	}
 	set_cursor_waiting(TRUE);
 	save_dialog(".csv", exportCSV);
 	set_cursor_waiting(FALSE);
@@ -705,19 +949,16 @@ void on_clearAllPhotometry_clicked(GtkButton *button, gpointer user_data) {
 
 gboolean on_DrawingPlot_draw(GtkWidget *widget, cairo_t *cr, gpointer data) {
 	guint width, height, i, j;
-	double mean, color;
-	int nb_graphs = 0;
-	struct kpair *avg;
 	struct kplotcfg cfgplot;
 	struct kdatacfg cfgdata;
-	struct kdata *d1, *ref_d, *mean_d;
-	struct kplot *p;
 
 	if (plot_data) {
+		struct kdata *d1, *ref_d, *mean_d, *curr_d;
 		pldata *plot = plot_data;
+
 		d1 = ref_d = mean_d = NULL;
 
-		color = (com.pref.combo_theme == 0) ? 0.0 : 1.0;
+		double color = (com.pref.combo_theme == 0) ? 0.0 : 1.0;
 
 		kplotcfg_defaults(&cfgplot);
 		kdatacfg_defaults(&cfgdata);
@@ -730,47 +971,78 @@ gboolean on_DrawingPlot_draw(GtkWidget *widget, cairo_t *cr, gpointer data) {
 		cfgplot.borderline.clr.rgba[2] = 0.5;
 		cfgplot.borderline.clr.rgba[3] = 1.0;
 		cfgplot.xaxislabel = xlabel == NULL ? _("Frames") : xlabel;
-		cfgplot.xtics = 3;
+		cfgplot.xtics = 5;
 		cfgplot.yaxislabel = ylabel;
 		cfgplot.yaxislabelrot = M_PI_2 * 3.0;
 		cfgplot.xticlabelpad = cfgplot.yticlabelpad = 10.0;
 		cfgdata.point.radius = 10;
 
-		p = kplot_alloc(&cfgplot);
+		struct kplot *p = kplot_alloc(&cfgplot);
 
 		// data plots
+		int nb_graphs = 0;
+
 		while (plot) {
 			d1 = kdata_array_alloc(plot->data, plot->nb);
+			if (X_selected_source == r_FRAME) {
 			kplot_attach_data(p, d1,
 					((plot_data->nb <= 100) ? KPLOT_LINESPOINTS : KPLOT_LINES),
 					NULL);
+			} else {
+				kplot_attach_data(p, d1, KPLOT_POINTS, NULL);
+			}
 			plot = plot->next;
 			nb_graphs++;
 		}
 
 		/* mean and min/max */
-		mean = kdata_ymean(d1);
+		double mean = kdata_ymean(d1);
 		//sigma = kdata_ystddev(d1);
 		int min_data = kdata_xmin(d1, NULL);
 		int max_data = kdata_xmax(d1, NULL);
 
-		if (nb_graphs == 1) {
-			avg = calloc((max_data - min_data) + 1, sizeof(struct kpair));
-			j = min_data;
-			for (i = 0; i < (max_data - min_data) + 1; i++) {
-				avg[i].x = plot_data->data[j].x;
-				avg[i].y = mean;
-				++j;
+		if (nb_graphs == 1 && plot_data->nb > 0) {
+			if ((!use_photometry) && ((registration_selected_source == r_FWHM) || (registration_selected_source == r_WFWHM) ||(registration_selected_source == r_ROUNDNESS) || (registration_selected_source == r_QUALITY))) {
+				if (X_selected_source == r_FRAME) {
+					struct kpair *sorted_data;
+					sorted_data = calloc(plot_data->nb, sizeof(struct kpair));
+					for (int i = 0; i < plot_data->nb; i++) {
+						sorted_data[i].x = plot_data->data[i].x;
+						sorted_data[i].y = plot_data->data[i].y;
+					}
+					qsort(sorted_data, plot_data->nb, sizeof(struct kpair), ((registration_selected_source == r_ROUNDNESS) || (registration_selected_source == r_QUALITY)) ? comparey_desc : comparey);
+					double imin = plot_data->data[min_data].x;
+					double imax = plot_data->data[max_data].x;
+					double pace = (imax - imin) / ((double)plot_data->nb - 1.);
+					for (int i = 0; i < plot_data->nb; i++) {
+						sorted_data[i].x = imin + (double)i * pace;
+					}
+					d1 = kdata_array_alloc(sorted_data, plot_data->nb);
+					kplot_attach_data(p, d1, KPLOT_LINES, NULL);
+					free(sorted_data);
+				}
+			} else if (use_photometry){
+				struct kpair *avg;
+				avg = calloc((max_data - min_data) + 1, sizeof(struct kpair));
+				j = min_data;
+				for (i = 0; i < (max_data - min_data) + 1; i++) {
+					avg[i].x = plot_data->data[j].x;
+					avg[i].y = mean;
+					++j;
+				}
+				mean_d = kdata_array_alloc(avg, (max_data - min_data) + 1);
+				kplot_attach_data(p, mean_d, KPLOT_LINES, NULL);	// mean plot
+				free(avg);
 			}
 
-			mean_d = kdata_array_alloc(avg, (max_data - min_data) + 1);
-			kplot_attach_data(p, mean_d, KPLOT_LINES, NULL);	// mean plot
-			free(avg);
-
 			if (ref.x >= 0.0 && ref.y >= 0.0) {
 				ref_d = kdata_array_alloc(&ref, 1);
 				kplot_attach_data(p, ref_d, KPLOT_POINTS, &cfgdata);	// ref image dot
 			}
+			if (curr.x >= 0.0 && curr.y >= 0.0) {
+				curr_d = kdata_array_alloc(&curr, 1);
+				kplot_attach_data(p, curr_d, KPLOT_MARKS, &cfgdata);	// ref image dot
+			}
 		}
 
 		width = gtk_widget_get_allocated_width(widget);
@@ -781,17 +1053,6 @@ gboolean on_DrawingPlot_draw(GtkWidget *widget, cairo_t *cr, gpointer data) {
 		cairo_fill(cr);
 		kplot_draw(p, width, height, cr);
 
-		/* copy graph colours for star highlight */
-		if (requires_color_update) {
-			for (i = 0; i < cfgplot.clrsz; i++) {
-				com.seq.photometry_colors[i][0] = cfgplot.clrs[i].rgba[0];
-				com.seq.photometry_colors[i][1] = cfgplot.clrs[i].rgba[1];
-				com.seq.photometry_colors[i][2] = cfgplot.clrs[i].rgba[2];
-			}
-			redraw(com.cvport, REMAP_ONLY);
-			requires_color_update = FALSE;
-		}
-
 		free_colors(&cfgplot);
 		kplot_free(p);
 		kdata_destroy(d1);
@@ -803,10 +1064,22 @@ gboolean on_DrawingPlot_draw(GtkWidget *widget, cairo_t *cr, gpointer data) {
 }
 
 void on_plotCombo_changed(GtkComboBox *box, gpointer user_data) {
+	if (use_photometry) {
+		photometry_selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));	
+	} else {
+		registration_selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));	
+	}
+	requires_seqlist_update = TRUE;
+	drawPlot();
+}
+
+void on_plotComboX_changed(GtkComboBox *box, gpointer user_data) {
+	X_selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(comboX));
 	drawPlot();
 }
 
 void on_arcsecPhotometry_toggled(GtkToggleButton *button, gpointer user_data) {
+	requires_seqlist_update = TRUE;
 	is_arcsec = gtk_toggle_button_get_active(button);
 	drawPlot();
 }
@@ -817,50 +1090,115 @@ void on_JulianPhotometry_toggled(GtkToggleButton *button, gpointer user_data) {
 }
 
 static void update_ylabel() {
-	selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
-	gtk_widget_set_sensitive(varCurve, selected_source == MAGNITUDE);
-	gboolean arcsec_is_ok = (gfit.focal_length > 0.0 && gfit.pixel_size_x > 0.f
-			&& gfit.pixel_size_y > 0.f && gfit.binning_x > 0
-			&& gfit.binning_y > 0);
-	gtk_widget_set_visible(arcsec, selected_source == FWHM && arcsec_is_ok);
-	switch (selected_source) {
-	case ROUNDNESS:
-		ylabel = _("Star roundness (1 is round)");
-		break;
-	case FWHM:
-		if (is_arcsec)
-			ylabel = _("FWHM ('')");
-		else
-			ylabel = _("FWHM (px)");
-		break;
-	case AMPLITUDE:
-		ylabel = _("Amplitude");
-		break;
-	case MAGNITUDE:
-		if (com.magOffset > 0.0 || com.seq.reference_star >= 0)
-			ylabel = _("Star magnitude (absolute)");
-		else
-			ylabel = _("Star magnitude (relative, use setmag)");
-		break;
-	case BACKGROUND:
-		ylabel = _("Background value");
-		break;
-	case X_POSITION:
-		ylabel = _("Star position on X axis");
-		break;
-	case Y_POSITION:
-		ylabel = _("Star position on Y axis");
-		break;
+	int current_selected_source = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
+	if (use_photometry) {
+		gtk_widget_set_sensitive(varCurve, current_selected_source == MAGNITUDE);
+		switch (current_selected_source) {
+			case ROUNDNESS:
+				ylabel = _("Star roundness (1 is round)");
+				break;
+			case FWHM:
+				ylabel = (is_arcsec) ? _("FWHM ('')") : _("FWHM (px)");
+				break;
+			case AMPLITUDE:
+				ylabel = _("Amplitude");
+				break;
+			case MAGNITUDE:
+				if (com.magOffset > 0.0 || com.seq.reference_star >= 0)
+					ylabel = _("Star magnitude (absolute)");
+				else
+					ylabel = _("Star magnitude (relative, use setmag)");
+				break;
+			case BACKGROUND:
+				ylabel = _("Background value");
+				break;
+			case X_POSITION:
+				ylabel = _("Star position on X axis");
+				break;
+			case Y_POSITION:
+				ylabel = _("Star position on Y axis");
+				break;
+			case SNR:
+				ylabel = _("SNR (dB)");
+				break;
+			default:
+				break;
+		}
+	} else {
+		switch (current_selected_source) {
+			case r_ROUNDNESS:
+				ylabel = _("Star roundness (1 is round)");
+				break;
+			case r_FWHM:
+				ylabel = (is_arcsec) ? _("FWHM ('')") : _("FWHM (px)");
+				break;
+			case r_WFWHM:
+				ylabel = (is_arcsec) ? _("wFWHM ('')") : _("wFWHM (px)");
+				break;
+			case r_X_POSITION:
+				ylabel = _("Star position on X axis");
+				break;
+			case r_Y_POSITION:
+				ylabel = _("Star position on Y axis");
+				break;
+			case r_QUALITY:
+				ylabel = _("Quality");
+				break;
+			default:
+				break;
+		}
+		switch (X_selected_source) {
+			case r_ROUNDNESS:
+				xlabel = _("Star roundness (1 is round)");
+				break;
+			case r_FWHM:
+				xlabel = (is_arcsec) ? _("FWHM ('')") : _("FWHM (px)");
+				break;
+			case r_WFWHM:
+				xlabel = (is_arcsec) ? _("wFWHM ('')") : _("wFWHM (px)");
+				break;
+			case r_X_POSITION:
+				xlabel = _("Star position on X axis");
+				break;
+			case r_Y_POSITION:
+				xlabel = _("Star position on Y axis");
+				break;
+			case r_QUALITY:
+				xlabel = _("Quality");
+				break;
+			case r_FRAME:
+				xlabel = _("Frames");
+				break;
+			default:
+				break;
+		}
+	}
+}
+
+/* initialize the colors of each star for photometry, outside
+ * on_DrawingPlot_draw because it may not be called if the panel is hidden, but
+ * the circles in the main image display still use these colors.
+ */
+static void init_plot_colors() {
+	struct kplotcfg cfgplot;
+	set_colors(&cfgplot);
+	/* copy graph colours for star highlight */
+	for (int i = 0; i < cfgplot.clrsz; i++) {
+		com.seq.photometry_colors[i][0] = cfgplot.clrs[i].rgba[0];
+		com.seq.photometry_colors[i][1] = cfgplot.clrs[i].rgba[1];
+		com.seq.photometry_colors[i][2] = cfgplot.clrs[i].rgba[2];
 	}
 }
 
 void notify_new_photometry() {
 	control_window_switch_to_tab(PLOT);
-	requires_color_update = TRUE;
-	gtk_widget_set_visible(sourceCombo, TRUE);
+	init_plot_colors();
+	gtk_widget_set_sensitive(sourceCombo, TRUE);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(sourceCombo), 1);
 	gtk_widget_set_sensitive(buttonClearLatest, TRUE);
 	gtk_widget_set_sensitive(buttonClearAll, TRUE);
+	gtk_widget_set_sensitive(comboX, FALSE);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(comboX), r_FRAME);
 }
 
 static void set_colors(struct kplotcfg *cfg) {
@@ -898,27 +1236,44 @@ static void free_colors(struct kplotcfg *cfg) {
 	free(cfg->clrs);
 }
 
-static int get_index_of_frame(gdouble x, gdouble y) {
-	if (!plot_data) return -1;
-	if (!com.seq.imgparam) return -1;
-
+static gboolean get_index_of_frame(gdouble x, gdouble y, gboolean check_index_incl, double *index, double *val, double *ypos) {
+	if (!plot_data) return FALSE;
+	if (!com.seq.imgparam) return FALSE;
+	double miny = DBL_MAX, maxy = - DBL_MAX;
+	double minx = DBL_MAX, maxx = - DBL_MAX;
 	pldata *plot = plot_data;
+	int closestframe = -1;
+	double mindist = DBL_MAX, dist;
 
-	point min = { plot->frame[0], plot->data[0].y };
-	/* ensure to correctly find max frame index */
-	int i = 0;
-	while (plot->frame[com.seq.selnum - 1 - i] == 0.0) {
-		i++;
+	for (int j = 0; j < plot->nb; j++) {
+		if (plot->data[j].x < minx) minx = plot->data[j].x;
+		if (plot->data[j].x > maxx) maxx = plot->data[j].x;
+		if (plot->data[j].y < miny) miny = plot->data[j].y;
+		if (plot->data[j].y > maxy) maxy = plot->data[j].y;
 	}
-	point max = { plot->frame[com.seq.selnum - 1 - i], plot->data[com.seq.selnum - 1 - i].y };
-	point intervale = { get_dimx() / (max.x - min.x), get_dimy() / (max.y - min.y)};
+
+	point intervale = { get_dimx() / (maxx - minx), get_dimy() / (maxy - miny)};
 	point pos = { x - get_offsx(), get_dimy() - y + get_offsy() };
 
-	int index = (int) round(pos.x / intervale.x) + (int) min.x - 1;
-	if (index >= 0 && index <= max.x && com.seq.imgparam[index].incl) {
-		return index;
+	*index = pos.x / intervale.x + minx;
+	*val = *index;
+	*ypos = pos.y / intervale.y + miny;
+
+	double invrangex = 1./(maxx - minx);
+	double invrangey = 1./(maxy - miny);
+
+	for (int j = 0; j < plot->nb; j++) {
+		dist = xpow((*index - plot->data[j].x) * invrangex, 2) + xpow((*ypos - plot->data[j].y) * invrangey, 2);
+		if (dist < mindist) {
+			mindist = dist;
+			closestframe = plot->frame[j];
+		}
 	}
-	return -1;
+	*index = (mindist < 0.0004) ? closestframe : -1; // only set index if distance between cursor and a point is small enough (2% of scales)
+
+	if (check_index_incl && (*index >= 0 && *index <= maxx)) return com.seq.imgparam[(int)*index - 1].incl;
+	return TRUE;
+
 }
 
 gboolean on_DrawingPlot_motion_notify_event(GtkWidget *widget,
@@ -926,10 +1281,17 @@ gboolean on_DrawingPlot_motion_notify_event(GtkWidget *widget,
 
 	gtk_widget_set_has_tooltip(widget, FALSE);
 
-	int index = get_index_of_frame(event->x, event->y);
-	if (index >= 0) {
-		gchar *tooltip_text = g_strdup_printf("Frame: %d", (index + 1));
+	double index, val, ypos;
+	gboolean getvals = get_index_of_frame(event->x, event->y, FALSE, &index, &val, &ypos);
+	gchar *tooltip_text;
+	if (getvals) {
+		if (index > 0) {
+			tooltip_text = g_strdup_printf("X pos: %0.3f\nY pos: %0.3f\nFrame#%d", val, ypos,(int)index);
+		} else {
+			tooltip_text = g_strdup_printf("X pos: %0.3f\nY pos: %0.3f", val, ypos);
+		}
 		gtk_widget_set_tooltip_text(widget, tooltip_text);
+		g_free(tooltip_text);
 		return TRUE;
 	}
 	return FALSE;
@@ -957,14 +1319,18 @@ gboolean on_DrawingPlot_leave_notify_event(GtkWidget *widget, GdkEvent *event,
 static void do_popup_plotmenu(GtkWidget *my_widget, GdkEventButton *event) {
 	static GtkMenu *menu = NULL;
 	static GtkMenuItem *menu_item = NULL;
+	static GtkMenuItem *menu_item2 = NULL;
 
-	int index = get_index_of_frame(event->x, event->y);
+	double index, val, ypos;
+	gboolean getvals = get_index_of_frame(event->x, event->y, TRUE, &index, &val, &ypos);
+	if (!getvals) return;
 	if (index < 0) return;
 
 	if (!menu) {
 		menu = GTK_MENU(lookup_widget("menu_plot"));
 		gtk_menu_attach_to_widget(GTK_MENU(menu), my_widget, NULL);
 		menu_item = GTK_MENU_ITEM(lookup_widget("menu_plot_exclude"));
+		menu_item2 = GTK_MENU_ITEM(lookup_widget("menu_plot_show"));
 	}
 
 #if GTK_CHECK_VERSION(3, 22, 0)
@@ -983,10 +1349,13 @@ static void do_popup_plotmenu(GtkWidget *my_widget, GdkEventButton *event) {
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, button,
 			event_time);
 #endif
-	gchar *str = g_strdup_printf(_("Exclude Frame %d"), index + 1);
+	gchar *str = g_strdup_printf(_("Exclude Frame %d"), (int)index);
 	gtk_menu_item_set_label(menu_item, str);
+	gchar*str2 = g_strdup_printf(_("Show Frame %d"), (int)index);
+	gtk_menu_item_set_label(menu_item2, str2);
 
 	g_free(str);
+	g_free(str2);
 }
 
 gboolean on_DrawingPlot_button_press_event(GtkWidget *widget,
@@ -999,12 +1368,12 @@ static signed long extract_int_from_label(const gchar *str) {
 	gchar *p = (gchar *)str;
 	while (*p) {
 		if (g_ascii_isdigit(*p) || ((*p == '-' || *p == '+') && g_ascii_isdigit(*(p + 1)))) {
-	        // Found a number
-	        return g_ascii_strtoll(p, &p, 10); // return number
-	    } else {
-	        // Otherwise, move on to the next character.
-	        p++;
-	    }
+			// Found a number
+			return g_ascii_strtoll(p, &p, 10); // return number
+		} else {
+			// Otherwise, move on to the next character.
+			p++;
+		}
 	}
 	return -1;
 }
@@ -1018,6 +1387,18 @@ void on_menu_plot_exclude_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		index--;
 
 		exclude_single_frame(index);
-		update_seqlist();
+		update_seqlist(use_photometry ? 0 : reglayer);
+	}
+}
+
+void on_menu_plot_show_activate(GtkMenuItem *menuitem, gpointer user_data) {
+	const gchar *label = gtk_menu_item_get_label(menuitem);
+	gint index;
+
+	index = extract_int_from_label(label);
+	if (index > 0) {
+		siril_open_dialog("seqlist_dialog");
+		update_seqlist(use_photometry ? 0 : reglayer);
+		sequence_list_select_row_from_index(index - 1, TRUE);
 	}
 }
