@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -37,14 +37,26 @@ typedef struct plot_data_struct {
 
 
 /* has to be the same as in the glade file */
-enum photmetry_source {
-	ROUNDNESS,
+enum photometry_source {
 	FWHM,
+	ROUNDNESS,
 	AMPLITUDE,
 	MAGNITUDE,
 	BACKGROUND,
 	X_POSITION,
-	Y_POSITION
+	Y_POSITION,
+	SNR
+};
+
+/* has to be the same as in the glade file */
+enum registration_source {
+	r_FWHM,
+	r_ROUNDNESS,
+	r_WFWHM,
+	r_QUALITY,
+	r_X_POSITION,
+	r_Y_POSITION,
+	r_FRAME
 };
 
 gchar *siril_win_get_gnuplot_path();
