@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -46,6 +46,14 @@
 
 #define SCALE_FLAGS SWS_BICUBIC
 
+static double vp9_quality_to_crf[]  = { 44.0, 38.0, 32.0, 26.0, 20.0 };
+static double x264_quality_to_crf[] = { 29.0, 26.0, 23.0, 20.0, 17.0 };
+static double x265_quality_to_crf[] = { 34.0, 31.0, 28.0, 25.0, 22.0 };
+
+#define CHECK_OPT_SET_RETVAL \
+	if (retval == AVERROR_OPTION_NOT_FOUND) { \
+		siril_log_color_message("A codec option was not found when configuring the export\n", "red"); \
+}
 
 static void log_packet(const AVFormatContext *fmt_ctx, const AVPacket *pkt)
 {
@@ -79,13 +87,17 @@ static int add_stream(struct mp4_struct *ost, AVCodec **codec,
 	/* find the encoder */
 	*codec = avcodec_find_encoder(codec_id);
 	if (!(*codec)) {
-		fprintf(stderr, "Could not find encoder for '%s'\n", avcodec_get_name(codec_id));
+		siril_log_message("Could not find encoder for '%s'\n", avcodec_get_name(codec_id));
+		return 1;
+	}
+	if ((*codec)->type != AVMEDIA_TYPE_VIDEO) {
+		siril_log_message("Codec '%s' is not a video codec\n", avcodec_get_name(codec_id));
 		return 1;
 	}
 
 	ost->st = avformat_new_stream(ost->oc, NULL);
 	if (!ost->st) {
-		fprintf(stderr, "Could not allocate stream\n");
+		siril_log_message("Could not allocate stream\n");
 		return 1;
 	}
 	ost->st->id = ost->oc->nb_streams-1;
@@ -96,30 +108,67 @@ static int add_stream(struct mp4_struct *ost, AVCodec **codec,
 	}
 	ost->enc = c;
 
-	switch ((*codec)->type) {
-		case AVMEDIA_TYPE_VIDEO:
-			c->codec_id = codec_id;
+	c->thread_count = com.max_thread;
 
-			c->bit_rate = ost->bitrate;
-			c->bit_rate_tolerance = 50000;
-			/* definition must be a multiple of two. */
-			c->width    = w;
-			c->height   = h;
-			/* timebase: This is the fundamental unit of time (in seconds) in terms
-			 * of which frame timestamps are represented. For fixed-fps content,
-			 * timebase should be 1/framerate and timestamp increments should be
-			 * identical to 1. */
-			ost->st->time_base = (AVRational){ 1, fps };
-			c->time_base       = ost->st->time_base;
-
-			c->gop_size      = 12; /* emit one intra frame every twelve frames at most */
-			c->pix_fmt       = STREAM_PIX_FMT;
+	c->codec_id = codec_id;
+	int retval;
+	int crf;
+	switch (codec_id) {
+		case AV_CODEC_ID_VP9:
+			c->bit_rate = 0;
+			/* for this codec, quality depends on image size (like bit rate) */
+			float size_factor = 5.0f * logf((float)(w * h) / (1920.0f * 1080.0f));
+			if (size_factor < -4.0f) size_factor = -4.0f;
+			crf = (int)(vp9_quality_to_crf[ost->quality - 1] - size_factor);
+			siril_debug_print("VP9 constant quality value: %d\n", crf);
+			retval = av_opt_set_int(c->priv_data, "crf", crf, 0); // For integer values
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set_int(c->priv_data, "speed", 1, 0);
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set_int(c->priv_data, "frame-parallel", 1, 0);
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set_int(c->priv_data, "lag-in-frames", 1, 0);
+			CHECK_OPT_SET_RETVAL;
+			break;
+		case AV_CODEC_ID_H264:
+			/* The range of the CRF scale is 0–51, where 0 is lossless, 23 is the
+			 * default, and 51 is worst quality possible. A subjectively sane range
+			 * is 17–28. Consider 17 or 18 to be visually lossless or nearly so. */
+			crf = x264_quality_to_crf[ost->quality - 1];
+			siril_debug_print("x264 constant quality value: %d\n", crf);
+			retval = av_opt_set_int(c->priv_data, "crf", crf, 0); // For integer values
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set(c->priv_data, "preset", "fast", 0);
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set(c->priv_data, "tune", "grain", 0);
+			CHECK_OPT_SET_RETVAL;
+			break;
+		case AV_CODEC_ID_H265:
+			// default is 28, it should visually correspond to libx264 video at CRF 23
+			crf = x265_quality_to_crf[ost->quality - 1];
+			siril_debug_print("x265 constant quality value: %d\n", crf);
+			retval = av_opt_set_int(c->priv_data, "crf", crf, 0); // For integer values
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set(c->priv_data, "preset", "fast", 0);
+			CHECK_OPT_SET_RETVAL;
+			retval = av_opt_set(c->priv_data, "tune", "grain", 0);
+			CHECK_OPT_SET_RETVAL;
 			break;
-
 		default:
-			fprintf(stderr, "strange case happening in stream addition\n");
 			break;
 	}
+	/* definition must be a multiple of two. */
+	c->width    = w;
+	c->height   = h;
+	/* timebase: This is the fundamental unit of time (in seconds) in terms
+	 * of which frame timestamps are represented. For fixed-fps content,
+	 * timebase should be 1/framerate and timestamp increments should be
+	 * identical to 1. */
+	ost->st->time_base = (AVRational){ 1, fps };
+	c->time_base       = ost->st->time_base;
+
+	c->gop_size      = 12; /* emit one intra frame every twelve frames at most */
+	c->pix_fmt       = STREAM_PIX_FMT;
 
 	/* Some formats want stream headers to be separate. */
 	if (ost->oc->oformat->flags & AVFMT_GLOBALHEADER)
@@ -133,10 +182,7 @@ static int add_stream(struct mp4_struct *ost, AVCodec **codec,
 
 static AVFrame *alloc_picture(enum AVPixelFormat pix_fmt, int width, int height)
 {
-	AVFrame *picture;
-	int ret;
-
-	picture = av_frame_alloc();
+	AVFrame *picture = av_frame_alloc();
 	if (!picture) {
 		PRINT_ALLOC_ERR;
 		return NULL;
@@ -147,9 +193,9 @@ static AVFrame *alloc_picture(enum AVPixelFormat pix_fmt, int width, int height)
 	picture->height = height;
 
 	/* allocate the buffers for the frame data */
-	ret = av_frame_get_buffer(picture, 32);
+	int ret = av_frame_get_buffer(picture, 32);
 	if (ret < 0) {
-		fprintf(stderr, "Could not allocate frame data.\n");
+		siril_log_message("Could not allocate video frame data.\n");
 		return NULL;
 	}
 
@@ -158,17 +204,16 @@ static AVFrame *alloc_picture(enum AVPixelFormat pix_fmt, int width, int height)
 
 static int open_video(AVCodec *codec, struct mp4_struct *ost, AVDictionary *opt_arg, int nb_layers)
 {
-	int ret;
 	AVCodecContext *c = ost->enc;
 	AVDictionary *opt = NULL;
 
 	av_dict_copy(&opt, opt_arg, 0);
 
 	/* open the codec */
-	ret = avcodec_open2(c, codec, &opt);
+	int ret = avcodec_open2(c, codec, &opt);
 	av_dict_free(&opt);
 	if (ret < 0) {
-		fprintf(stderr, "Could not open video codec: %s\n", av_err2str(ret));
+		siril_log_message("Could not open video codec: %s\n", av_err2str(ret));
 		return 1;
 	}
 
@@ -176,7 +221,7 @@ static int open_video(AVCodec *codec, struct mp4_struct *ost, AVDictionary *opt_
 	ost->frame = alloc_picture(c->pix_fmt, c->width, c->height);
 	if (!ost->frame) {
 		PRINT_ALLOC_ERR;
-		fprintf(stderr, "Could not allocate video frame\n");
+		siril_log_message("Could not allocate video frame\n");
 		return 1;
 	}
 
@@ -188,15 +233,21 @@ static int open_video(AVCodec *codec, struct mp4_struct *ost, AVDictionary *opt_
 		ost->tmp_frame = alloc_picture(pix_fmt, ost->src_w, ost->src_h);
 		if (!ost->tmp_frame) {
 			PRINT_ALLOC_ERR;
-			fprintf(stderr, "Could not allocate temporary picture\n");
+			siril_log_message("Could not allocate temporary picture\n");
 			return 1;
 		}
 	}
 
+	ost->pkt = av_packet_alloc();
+	if (!ost->pkt) {
+		PRINT_ALLOC_ERR;
+		return 1;
+	}
+
 	/* copy the stream parameters to the muxer */
 	ret = avcodec_parameters_from_context(ost->st->codecpar, c);
 	if (ret < 0) {
-		fprintf(stderr, "Could not copy the stream parameters\n");
+		siril_log_message("Could not copy the stream parameters\n");
 		return 1;
 	}
 
@@ -219,13 +270,12 @@ static int fill_rgb_image(AVFrame *pict, int frame_index,
 		return 1;
 
 	BYTE map[USHRT_MAX + 1];
-	WORD tmp_pixel_value, hi, lo;
 	int i;
 	
-	float slope = compute_slope(&lo, &hi);
+	float slope = (fit->orig_bitpix == BYTE_IMG) ? 1.0f : UCHAR_MAX_SINGLE / USHRT_MAX_SINGLE;
 
 	for (i = 0; i <= USHRT_MAX; i++) {
-		map[i] = round_to_BYTE((float) i * slope);
+		map[i] = roundf_to_BYTE((float) i * slope);
 		if (map[i] == UCHAR_MAX)
 			break;
 	}
@@ -245,11 +295,7 @@ static int fill_rgb_image(AVFrame *pict, int frame_index,
 			int srcpixel = y * fit->rx;
 			int dstpixel = desty * fit->rx;
 			for (x = 0; x < fit->rx; x++, srcpixel++, dstpixel++) {
-				// linear scaling
-				if (src[srcpixel] - lo < 0)
-					tmp_pixel_value = 0;
-				else 	tmp_pixel_value = src[srcpixel] - lo;
-				dst[dstpixel] = map[tmp_pixel_value];
+				dst[dstpixel] = map[src[srcpixel]];
 			}
 		}
 	} else {
@@ -263,11 +309,7 @@ static int fill_rgb_image(AVFrame *pict, int frame_index,
 				int srcpixel = y * fit->rx;
 				int dstpixel = (desty * fit->rx * 3) + channel;
 				for (x = 0; x < fit->rx; x++, srcpixel++, dstpixel+=3) {
-					// linear scaling
-					if (src[srcpixel] - lo < 0)
-						tmp_pixel_value = 0;
-					else 	tmp_pixel_value = src[srcpixel] - lo;
-					dst[dstpixel] = map[tmp_pixel_value];
+					dst[dstpixel] = map[src[srcpixel]];
 				}
 			}
 		}
@@ -296,8 +338,7 @@ static AVFrame *get_video_frame(struct mp4_struct *ost, fits *input_image)
 					c->width, c->height, c->pix_fmt,
 					SCALE_FLAGS, NULL, NULL, NULL);
 			if (!ost->sws_ctx) {
-				fprintf(stderr,
-						"Could not initialize the conversion context\n");
+				siril_log_message("Could not initialize the conversion context\n");
 				return NULL;
 			}
 		}
@@ -321,71 +362,70 @@ static AVFrame *get_video_frame(struct mp4_struct *ost, fits *input_image)
  */
 static int write_video_frame(struct mp4_struct *ost, fits *input_image)
 {
-	int ret;
 	AVCodecContext *c = ost->enc;
-	AVPacket pkt = { 0 };
-	fprintf(stdout, "writing video frame\n");
+
+	siril_debug_print("writing video frame\n");
 
 	ost->frame = get_video_frame(ost, input_image);
 
-	av_init_packet(&pkt);
-
 	/* encode the image */
-	ret = avcodec_send_frame(c, ost->frame);
+	int ret = avcodec_send_frame(c, ost->frame);
 	if (ret < 0) {
-		fprintf(stderr, "Error encoding video frame: %s\n", av_err2str(ret));
+		av_packet_unref(ost->pkt);
+		siril_log_message("Error encoding video frame: %s\n", av_err2str(ret));
 		return 1;
 	}
 
-	ret = avcodec_receive_packet(c, &pkt);
-	if (ret == 0) {
-		ret = write_frame(ost->oc, &c->time_base, ost->st, &pkt);
-		if (ret < 0) {
-			fprintf(stderr, "Error while writing video frame: %s\n", av_err2str(ret));
-			return 1;
-		}
-	}
+	ret = avcodec_receive_packet(c, ost->pkt);
+	if (ret == AVERROR(EAGAIN))
+		return 0;
 	else if (ret == AVERROR(EINVAL)) {
-		fprintf(stderr, "Error while getting video packet: %s\n", av_err2str(ret));
+		siril_log_message("Error while getting video packet: %s\n", av_err2str(ret));
 		return 1;
 	}
 	else if (ret == AVERROR_EOF) {
-		fprintf(stderr, "End of stream met while adding a frame\n");
+		siril_log_message("End of stream met while adding a frame\n");
+		return 1;
+	}
+	else if (ret < 0) {
+		siril_log_message("Error while getting video packat %s\n", av_err2str(ret));
+		return 1;
+	}
+
+	ret = write_frame(ost->oc, &c->time_base, ost->st, ost->pkt);
+	av_packet_unref(ost->pkt);
+	if (ret < 0) {
+		siril_log_message("Error while writing video frame: %s\n", av_err2str(ret));
 		return 1;
 	}
-	else if (ret == AVERROR(EAGAIN))
-		return 0;
-	//else retry later
 	return 0;
 }
 
 static void flush_stream(struct mp4_struct *ost)
 {
 	int ret;
-	AVPacket pkt = { 0 };
-	av_init_packet(&pkt);
 
 	ret = avcodec_send_frame(ost->enc, NULL);
 	if (ret < 0) {
-		fprintf(stderr, "Error encoding video frame: %s\n", av_err2str(ret));
+		siril_log_message("Error encoding video frame: %s\n", av_err2str(ret));
 		return;
 	}
 
 	do {
-		ret = avcodec_receive_packet(ost->enc, &pkt);
+		ret = avcodec_receive_packet(ost->enc, ost->pkt);
 		if (ret == 0) {
-			ret = write_frame(ost->oc, &ost->enc->time_base, ost->st, &pkt);
+			ret = write_frame(ost->oc, &ost->enc->time_base, ost->st, ost->pkt);
 			if (ret < 0) {
-				fprintf(stderr, "Error while writing video frame: %s\n", av_err2str(ret));
+				siril_log_message("Error while writing video frame: %s\n", av_err2str(ret));
 				return;
 			}
 		}
 		else if (ret == AVERROR(EINVAL)) {
-			fprintf(stderr, "Error while getting video packet: %s\n", av_err2str(ret));
+			siril_log_message("Error while getting video packet: %s\n", av_err2str(ret));
 			return;
 		}
 	}
-	while (ret != AVERROR_EOF) ;
+	while (ret != AVERROR_EOF);
 }
 
 static void close_stream(struct mp4_struct *ost)
@@ -420,37 +460,28 @@ struct mp4_struct *mp4_create(const char *filename, int dst_w, int dst_h, int fp
 	/* allocate the output media context */
 	avformat_alloc_output_context2(&video_st->oc, NULL, NULL, filename);
 	if (!video_st->oc) {
-		fprintf(stdout, "Could not deduce output format from file extension: using mp4.\n");
+		siril_log_message("Could not deduce output format from file extension: using mp4.\n");
 		avformat_alloc_output_context2(&video_st->oc, NULL, "mp4", filename);
 		if (!video_st->oc) {
 			free(video_st);
-			fprintf(stderr, "FFMPEG does not seem to support mp4 format, aborting.\n");
+			siril_log_message("FFMPEG does not seem to support mp4 format, aborting.\n");
 			return NULL;
 		}
 	}
 
 	video_st->fmt = video_st->oc->oformat;
+	video_st->quality = quality;
 	/* disable unwanted features, is this the correct way? */
 	video_st->fmt->audio_codec = AV_CODEC_ID_NONE;
-	/* Calculating bitrate: it depends on the codec and the amount of image data.
-	 * For h264, the Kush gauge is widely used, giving a bitrate of :
-	 * pixel count x framerate x motion factor x 0.07
-	 * with motion factor: 1 - 4 depending on how much pixels change between frames.
-	 * We can use that as a quality factor (1 - 5)
-	 * For other codecs, we can change the constant factor of 0.07 to an estimated quality
-	 * difference, for example 0.45 for h265 and 0.4 for VP9 */
 	switch(type) {
 	case EXPORT_WEBM_VP9:
 		video_st->fmt->video_codec = AV_CODEC_ID_VP9;
-		video_st->bitrate = (int64_t)(0.04f * (float) dst_w * (float) dst_h * (float) fps * (float) quality);
 		break;
 	case EXPORT_MP4:
 		video_st->fmt->video_codec = AV_CODEC_ID_H264;
-		video_st->bitrate = (int64_t)(0.07f * (float) dst_w * (float) dst_h * (float) fps * (float) quality);
 		break;
 	case EXPORT_MP4_H265:
 		video_st->fmt->video_codec = AV_CODEC_ID_H265;
-		video_st->bitrate = (int64_t)(0.045f * (float) dst_w * (float) dst_h * (float) fps * (float) quality);
 		break;
 	default:
 		fprintf(stderr, "mp4_create: unknown type, should not happen\n");
@@ -464,12 +495,12 @@ struct mp4_struct *mp4_create(const char *filename, int dst_w, int dst_h, int fp
 		if (add_stream(video_st, &video_codec, video_st->fmt->video_codec, dst_w, dst_h, fps)) {
 			avformat_free_context(video_st->oc);
 			free(video_st);
-			fprintf(stderr, "Could not add the video stream in the output film, aborting\n");
+			siril_log_message("Could not add the video stream in the output film, aborting\n");
 			return NULL;
 		}
 	} else {
 		avformat_free_context(video_st->oc);
-		fprintf(stderr, "Error setting video codec for output file.");
+		siril_log_message("Error setting video codec for output file.");
 		return NULL;
 	}
 
@@ -487,7 +518,7 @@ struct mp4_struct *mp4_create(const char *filename, int dst_w, int dst_h, int fp
 	/* open the output file, if needed */
 	if (!(video_st->fmt->flags & AVFMT_NOFILE)) {
 		if ((ret = avio_open(&video_st->oc->pb, filename, AVIO_FLAG_WRITE)) < 0) {
-			fprintf(stderr, "Could not open '%s': %s\n", filename, av_err2str(ret));
+			siril_log_message("Could not open '%s': %s\n", filename, av_err2str(ret));
 			avformat_free_context(video_st->oc);
 			avcodec_free_context(&video_st->enc);
 			av_frame_free(&video_st->frame);
@@ -499,7 +530,7 @@ struct mp4_struct *mp4_create(const char *filename, int dst_w, int dst_h, int fp
 
 	/* Write the stream header, if any. */
 	if ((ret = avformat_write_header(video_st->oc, &opt)) < 0) {
-		fprintf(stderr, "Error occurred when opening output file: %s\n", av_err2str(ret));
+		siril_log_message("Error occurred when opening output file: %s\n", av_err2str(ret));
 		avformat_free_context(video_st->oc);
 		avcodec_free_context(&video_st->enc);
 		av_frame_free(&video_st->frame);
@@ -519,12 +550,13 @@ int mp4_add_frame(struct mp4_struct *video_st, fits *image) {
 	}
 
 	/* should never happen, because we don't limit it */
-	fprintf(stderr, "End of video stream\n");
+	siril_log_message("End of video stream\n");
 	return -1;
 }
 
-int mp4_close(struct mp4_struct *video_st) {
-	flush_stream(video_st);
+int mp4_close(struct mp4_struct *video_st, gboolean aborted) {
+	if (!aborted)
+		flush_stream(video_st);
 
 	/* Write the trailer, if any. The trailer must be written before you
 	 * close the CodecContexts open when you wrote the header; otherwise
@@ -545,7 +577,8 @@ int mp4_close(struct mp4_struct *video_st) {
 	av_frame_free(&video_st->frame);
 	if (video_st->tmp_frame)
 		av_frame_free(&video_st->tmp_frame);
-
+	av_packet_unref(video_st->pkt);
+	av_packet_free(&(video_st->pkt));
 	return 0;
 }
 
