@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2022 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -60,9 +60,9 @@
 #include "registration/registration.h"
 
 /* the global variables of the whole project */
-cominfo com;	// the main data struct
+cominfo com;	// the core data struct
+guiinfo gui;	// the gui data struct
 fits gfit;	// currently loaded image
-GtkBuilder *builder = NULL;	// get widget references anywhere
 const gchar *startup_cwd = NULL;
 gboolean forcecwd = FALSE;
 
@@ -82,6 +82,13 @@ static gboolean _print_version_and_exit(const gchar *option_name,
 	return TRUE;
 }
 
+static gboolean _print_copyright_and_exit(const gchar *option_name,
+		const gchar *value, gpointer data, GError **error) {
+	g_print("Copyright © 2012-%s team free-astro\n", SIRIL_GIT_LAST_COMMIT_YEAR);
+	exit(EXIT_SUCCESS);
+	return TRUE;
+}
+
 static gboolean _print_list_of_formats_and_exit(const gchar *option_name,
 		const gchar *value, gpointer data, GError **error) {
 	list_format_available();
@@ -96,29 +103,27 @@ static GOptionEntry main_option[] = {
 	{ "pipe", 'p', 0, G_OPTION_ARG_NONE, &main_option_pipe, N_("run in console mode with command and log stream through named pipes"), NULL },
 	{ "format", 'f', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, _print_list_of_formats_and_exit, N_("print all supported image file formats (depending on installed libraries)" ), NULL },
 	{ "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, _print_version_and_exit, N_("print the application’s version"), NULL},
+	{ "copyright", 'c', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, _print_copyright_and_exit, N_("print the copyright"), NULL},
 	{ NULL },
 };
 
 static void global_initialization() {
-	com.cvport = RED_VPORT;
-	com.show_excluded = TRUE;
 	com.selected_star = -1;
 	com.star_is_seqdata = FALSE;
 	com.stars = NULL;
+	com.qphot = NULL;
+	com.tilt = NULL;
 	com.uniq = NULL;
-	com.color = NORMAL_COLOR;
-	for (int i = 0; i < MAXVPORT; i++)
-		com.buf_is_dirty[i] = TRUE;
 	memset(&com.selection, 0, sizeof(rectangle));
 	memset(com.layers_hist, 0, sizeof(com.layers_hist));
-	/* initialize the com struct and zoom level */
-	com.sliders = MINMAX;
-	com.zoom_value = ZOOM_DEFAULT;
-	com.pref.font_scale = 100.0;
-	/* first initialization of compression settings */
-	com.pref.comp.fits_enabled = FALSE;
-	com.pref.comp.fits_method = 0;
-	com.pref.comp.fits_quantization = 16;
+
+	gui.cvport = RED_VPORT;
+	gui.show_excluded = TRUE;
+	//gui.color = NORMAL_COLOR;
+	gui.sliders = MINMAX;
+	gui.zoom_value = ZOOM_DEFAULT;
+
+	initialize_default_preferences();
 }
 
 static void init_num_procs() {
@@ -143,6 +148,13 @@ static void init_num_procs() {
 static void siril_app_activate(GApplication *application) {
 	gchar *cwd_forced = NULL;
 
+	/*
+	 * Force C locale for numbers to avoid "," being used as decimal separator.
+	 * Called here and not in main() because setlocale(LC_ALL, "") is called as
+	 * part of g_application_run().
+	 */
+	setlocale(LC_NUMERIC, "C");
+
 	memset(&com, 0, sizeof(struct cominf));	// needed? doesn't hurt
 	com.initfile = NULL;
 
@@ -198,7 +210,7 @@ static void siril_app_activate(GApplication *application) {
 		if (g_strcmp0(main_option_script, "-") == 0) {
 			input_stream = siril_input_stream_from_stdin();
 		} else {
-			GError *error;
+			GError *error = NULL;
 			GFile *file = g_file_new_for_path(main_option_script);
 			if (file)
 				input_stream = (GInputStream *)g_file_read(file, NULL, &error);
@@ -368,8 +380,6 @@ int main(int argc, char *argv[]) {
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
-	g_setenv("LC_NUMERIC", "C", TRUE); // avoid possible bugs using french separator ","
-
 	app = g_application_new("org.free_astro.siril", G_APPLICATION_HANDLES_OPEN | G_APPLICATION_NON_UNIQUE);
 
 	g_signal_connect(app, "activate", G_CALLBACK(siril_app_activate), NULL);
