@@ -121,9 +121,9 @@ static int prepare_to_recalc(int num_matched_A,
 		struct s_star *matched_list_B, struct s_star *star_list_A_copy,
 		TRANS *trans);
 
-int new_star_match(fitted_PSF **s1, fitted_PSF **s2, int n, int nobj_override,
+int new_star_match(psf_star **s1, psf_star **s2, int n, int nobj_override,
 		double s_min, double s_max,
-		Homography *H, gboolean print_output) {
+		Homography *H, gboolean print_output, transformation_type type, s_star *out_list_A, s_star *out_list_B) {
 	int ret;
 	int numA, numB;
 	int num_matched_A, num_matched_B;
@@ -419,7 +419,7 @@ int new_star_match(fitted_PSF **s1, fitted_PSF **s2, int n, int nobj_override,
 	Hom->pair_matched = num_matches;
 
 	if (atPrepareHomography(num_matched_A, matched_list_A, num_matched_B,
-			matched_list_B, Hom, print_output)) {
+			matched_list_B, Hom, print_output, type)) {
 		fprintf(stderr,"atPrepareHomography fails on computing H\n");
 		/** */
 		atTransDel(trans);
@@ -435,12 +435,15 @@ int new_star_match(fitted_PSF **s1, fitted_PSF **s2, int n, int nobj_override,
 
 	print_H(Hom);
 	*H = *Hom;
+	*out_list_A = *matched_list_A;
+	*out_list_B = *matched_list_B;
+
 
 	/* clean up memory */
 	atTransDel(trans);
 	atHDel(Hom);
-	free_stars(matched_list_A);
-	free_stars(matched_list_B);
+	// free_stars(matched_list_A);
+	// free_stars(matched_list_B);
 	free_stars(star_list_A);
 	free_stars(star_list_B);
 	free_stars(star_list_A_copy);
@@ -505,7 +508,6 @@ struct s_star *post_list_A, /* I/O: stars in A, after they have */
 struct s_star *pre_list_A /* I: stars in A, with original coords */
 ) {
 	int post_index;
-	int found_it;
 	struct s_star *pre_star, *post_star;
 
 	/* if handed empty list, do nothing. */
@@ -523,7 +525,7 @@ struct s_star *pre_list_A /* I: stars in A, with original coords */
 
 		g_assert(post_star != NULL);
 
-		found_it = 0;
+		int found_it = 0;
 		pre_star = pre_list_A;
 		while (pre_star != NULL) {
 
