@@ -170,7 +170,7 @@ read_star_file(char *filename, int xcolumn, int ycolumn, int magcolumn,
     */
 
 int
-get_stars(fitted_PSF **s, int n, int *num_stars, struct s_star **list);
+get_stars(psf_star **s, int n, int *num_stars, struct s_star **list);
 
 void
 free_stars(struct s_star *head);
