@@ -10,33 +10,6 @@
 struct registration_args;
 typedef int (*registration_function)(struct registration_args *);
 
-/* arguments passed to registration functions */
-struct registration_args {
-	registration_function func;	// the registration function
-	sequence *seq;			// the sequence to register
-	int reference_image;		// reference image index
-	gboolean process_all_frames;	// all frames of the sequence (opposite of selected frames)
-	int layer;			// layer of images on which the registration is computed
-	int retval;			// retval of func
-	gboolean run_in_thread;		// true if the registration was run in a thread
-	gboolean follow_star;		// follow star position between frames
-	gboolean matchSelection;	// Match stars found in the seleciton of reference image
-	rectangle selection;		// the selection rectangle
-	gboolean x2upscale;		// apply an x2 upscale for pseudo drizzle
-	gboolean cumul;			// cumul reg data with previous one
-	int min_pairs;			// Minimum number of star pairs for success
-
-	/* data for generated sequence, for star alignment registration */
-	gboolean translation_only;	// don't rotate images => no new sequence
-	int new_total;                  // remaining images after registration
-	imgdata *imgparam;		// imgparam for the new sequence
-	regdata *regparam;		// regparam for the new sequence
-	const gchar *prefix;		// prefix of the created sequence if any
-	gboolean load_new_sequence;	// load the new sequence if success
-	const gchar *new_seq_name;
-	opencv_interpolation interpolation; // type of rotation interpolation
-};
-
 typedef enum {
 	REQUIRES_NO_SELECTION,	// selection is not used
 	REQUIRES_ANY_SELECTION,		// selection can be of any size and shape
@@ -58,6 +31,41 @@ typedef enum {
 	REG_PAGE_MISC
 } reg_notebook_page;
 
+typedef enum {
+	SHIFT_TRANSFORMATION,
+	SIMILARITY_TRANSFORMATION,
+	AFFINE_TRANSFORMATION,
+	HOMOGRAPHY_TRANSFORMATION
+} transformation_type;
+
+/* arguments passed to registration functions */
+struct registration_args {
+	registration_function func;	// the registration function
+	sequence *seq;			// the sequence to register
+	int reference_image;		// reference image index
+	gboolean process_all_frames;	// all frames of the sequence (opposite of selected frames)
+	int layer;			// layer of images on which the registration is computed
+	int retval;			// retval of func
+	gboolean run_in_thread;		// true if the registration was run in a thread
+	gboolean follow_star;		// follow star position between frames
+	gboolean matchSelection;	// Match stars found in the seleciton of reference image
+	rectangle selection;		// the selection rectangle
+	gboolean x2upscale;		// apply an x2 upscale for pseudo drizzle
+	gboolean cumul;			// cumul reg data with previous one
+	int min_pairs;			// Minimum number of star pairs for success
+	transformation_type type;   // Use affine transform  or homography
+
+	/* data for generated sequence, for star alignment registration */
+	gboolean translation_only;	// don't rotate images => no new sequence
+	int new_total;                  // remaining images after registration
+	imgdata *imgparam;		// imgparam for the new sequence
+	regdata *regparam;		// regparam for the new sequence
+	const gchar *prefix;		// prefix of the created sequence if any
+	gboolean load_new_sequence;	// load the new sequence if success
+	const gchar *new_seq_name;
+	opencv_interpolation interpolation; // type of rotation interpolation
+};
+
 /* used to register a registration method */
 struct registration_method {
 	const char *name;
@@ -76,6 +84,7 @@ int register_star_alignment(struct registration_args *args);
 int register_ecc(struct registration_args *args);
 int register_comet(struct registration_args *regargs);
 int register_3stars(struct registration_args *regargs);
+void reset_3stars();
 
 pointf get_velocity();
 void update_reg_interface(gboolean dont_change_reg_radio);
@@ -94,7 +103,7 @@ int get_registration_layer(sequence *seq);
 struct star_align_data {
 	struct registration_args *regargs;
 	regdata *current_regdata;
-	fitted_PSF **refstars;
+	psf_star **refstars;
 	int fitted_stars;
 	BYTE *success;
 	point ref;
